<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */

if (!class_exists('admin_folder_Redux_Framework_config')) {

    class admin_folder_Redux_Framework_config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if ( true == Redux_Helpers::isTheme( __FILE__ ) ) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }

        }

        public function initSettings() {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            add_action( 'redux/loaded', array( $this, 'remove_demo' ) );
            
            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 3);
            
            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );
            
            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );
            
            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**

          This is a test function that will let you see when the compiler hook occurs.
          It only runs if a field	set with compiler=>true is changed.

         * */
        function compiler_action($options, $css) {
            //echo '<h1>The compiler hook has run!';
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )

            
              // Demo of how to use the dynamic CSS and write your own static CSS file
              $filename = dirname(__FILE__) . '/style.css';
              global $wp_filesystem;
              if( empty( $wp_filesystem ) ) {
                require_once( ABSPATH .'/wp-admin/includes/file.php' );
              WP_Filesystem();
              }

              if( $wp_filesystem ) {
                $wp_filesystem->put_contents(
                    $filename,
                    $css,
                    FS_CHMOD_FILE // predefined mode settings for WP files
                );
              }
             
        }

        /**

          Custom function for filtering the sections array. Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            $sections[] = array(
                'title' => __('Section via hook', '_supermenu_'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', '_supermenu_'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            $args['dev_mode'] = false;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {

            /**
              Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $sample_patterns_path   = ReduxFramework::$_dir . '../sample/patterns/';
            $sample_patterns_url    = ReduxFramework::$_url . '../sample/patterns/';
            $sample_patterns        = array();

            if (is_dir($sample_patterns_path)) :

                if ($sample_patterns_dir = opendir($sample_patterns_path)) :
                    $sample_patterns = array();

                    while (( $sample_patterns_file = readdir($sample_patterns_dir) ) !== false) {

                        if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                            $name = explode('.', $sample_patterns_file);
                            $name = str_replace('.' . end($name), '', $sample_patterns_file);
                            $sample_patterns[]  = array('alt' => $name, 'img' => $sample_patterns_url . $sample_patterns_file);
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', '_supermenu_'), $this->theme->display('Name'));
            
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview'); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview'); ?>" />
                <?php endif; ?>

                <h4><?php echo $this->theme->display('Name'); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', '_supermenu_'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', '_supermenu_'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', '_supermenu_') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo $this->theme->display('Description'); ?></p>
            <?php
            if ($this->theme->parent()) {
                printf(' <p class="howto">' . __('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.') . '</p>', __('http://codex.wordpress.org/Child_Themes', '_supermenu_'), $this->theme->parent()->display('Name'));
            }
            ?>

                </div>
            </div>
            
						
            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

            $sampleHTML = '';
            if (file_exists(dirname(__FILE__) . '/info-html.html')) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once(ABSPATH . '/wp-admin/includes/file.php');
                    WP_Filesystem();
                }
                $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
            }

            // ACTUAL DECLARATION OF SECTIONS  
            /******************************************
						INTEGRATION CENTER
						******************************************/
            $this->sections[] = array(
                'title'     => __('Integration', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-asterisk',
                
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
	                    array(
	                        'id'        => 'sm-automatic-integration',
	                        'type'      => 'switch',
	                        'title'     => __('Integrate Automatically with your theme', '_supermenu_'),
	                        'subtitle'  => __('This will attempt to add the Supermenu code after the body tag.', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => true,
	                    ),
	                    array(
	                        'id'        => 'sm-theme-menu',
	                        'type'      => 'switch',
	                        'title'     => __('Hide your theme\'s Menu', '_supermenu_'),
	                        'subtitle'  => __('Use this option if you have two menus - Supermenu and your theme\'s menu. This is where you can hide your theme\'s menu without getting into code.', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => false,
	                    ),
	                    array(
                        'id'        => 'sm-attempt-theme-menu-hide',
                        'type'      => 'button_set',
                        'title'     => __('Choose how to hide your theme\'s Menu', 'redux-framework-demo'),
                        'subtitle'  => __('', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'options'   => array(
                        		'auto_class' 						=> 'Try common classes used by themes',
                            'manual_class' 					=> 'Manually Enter your theme\'s menu class'
                        ), 
                        'default'   => 'auto_class',
                        'required'  		=> array('sm-theme-menu', '=', true)
                    ),
                    array(
                            'id'       => 'sm-theme-menu-class',
                            'type'     => 'select',
                            'title'    => __( 'Try theme popular clases.', '_supermenu_' ),
                            'subtitle' => __( 'We have put  together a few classes used by themes and if your theme uses any of these classes, your menu will stop showing up.', '_supermenu_' ),
                            'desc'     => __( 'You could try them all to see if any works for you. If none hides your menu, you\'ll have to use the Manual option above.', '_supermenu_' ),
                            //Must provide key => value pairs for select options
                            'options'  => array(
                                'sm-no-class' 			=> 'CHOOSE',
                                'header'						=> 'header',
                                'site-header'				=> 'site-header',
                                'header-wrapper' 		=> 'header-wrapper',
                                'masthead' 					=> 'masthead',
                                'navbar'						=> 'navbar',
                                'navbar-wrap' 			=> 'navbar-wrap',
                                'navbar-wrapper' 		=> 'navbar-wrapper',
                                'menu-wrap' 				=> 'menu-wrap',
                                'menu-wrapper' 			=> 'menu-wrapper',
																'topmenu' 					=> 'topmenu',
																'topmenu-wrap' 			=> 'topmenu-wrap',
																'topmenu-wrapper' 	=> 'topmenu-wrapper',
                                
                            ),
                            'default'  => 'sm-no-class',
                            'required'  		=> array('sm-attempt-theme-menu-hide', '=', 'auto_class')
                        ),
                    array(
												    'id'       => 'sm-theme-manual-class',
												    'type'     => 'text',
												    'title'    => __('Enter your theme\'s menu class/ID.', 'redux-framework-demo'),
												    'subtitle' => __('<a href="http://boldblocks.com/support/supermenu/how-to-find-your-themes-menu-selector-classid/" target="_blank">How to Find your Menu\'s class.</a> Example: .mastheader, #fixed_menu', 'redux-framework-demo'),
												    'desc'     => __('You can add multiple classes or IDs.', 'redux-framework-demo'),
												    'validate' => 'no_html',
												    'msg'      => 'custom error message',
												    'default'  => '',
												    'required'  		=> array('sm-attempt-theme-menu-hide', '=', 'manual_class')
												),
	               ),
            );
            
            /******************************************
						FEATURE CONTROL
						******************************************/
            $this->sections[] = array(
                'title'     => __('Feature Control', '_supermenu_'),
                'desc'      => __('You can choose to globally enable or disable features from here.', '_supermenu_'),
                'icon'      => 'el-icon-unlock',
                
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
	                    //Top menu configs begin here
	                    array(
	                        'id'        => 'sm-top-menu',
	                        'type'      => 'switch',
	                        'title'     => __('Enable Top Menu?', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'subtitle'  => __('', '_supermenu_'),
	                        'default'   => true,
	                    ),
	                    array(
	                        'id'        => 'sm-topmenu-logo-control',
	                        'type'      => 'switch',
	                        'title'     => __('Show Logo in Top Menu?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => true,
	                        'required'  		=> array('sm-top-menu', '=', true)
	                    ),
	                    array(
	                        'id'        => 'sm-topmenu-menu-items',
	                        'type'      => 'switch',
	                        'title'     => __('Show Menu Icons in Top Menu?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => true,
	                        'required'  		=> array('sm-top-menu', '=', true)
	                    ),
	                    //Top menu configs end here
	                    array(
	                        'id'        => 'sm-superside-menu',
	                        'type'      => 'switch',
	                        'title'     => __('Enable Superside Menu?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => true,
	                    ),
	                    array(
	                        'id'        => 'sm-superside-logo-control',
	                        'type'      => 'switch',
	                        'title'     => __('Show Logo Icon in Superside Menu?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => true,
	                        'required'  		=> array('sm-superside-menu', '=', true)
	                    ),
	               ),
            );
            
            /******************************************
						*DIVIDER
						******************************************/
						$this->sections[] = array(
                'type' => 'divide', 
            );
            
            /******************************************
						*PRESETS
						******************************************/
            $this->sections[] = array(
                'title'     => __('Presets', '_supermenu_'),
                'desc'      => __('Here are some nice Presets for you to install with a single click. Note that all your settings would be overwritten, we recommend exporting your current settings before using a preset just to be on a safe side.', '_supermenu_'),
                'icon'      => 'el-icon-idea',
                
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
	                    
	                    array(
                            'id'       => 'sm-presets',
                            'type'     => 'image_select',
                            'presets'  => true,
                            'title'    => __( 'Preset Menu Style', '_supermenu_' ),
                            'subtitle' => __( 'Hold on till the next version! They\'ll get back their awesomeness very soon!', '_supermenu_' ),
                            'default'  => 0,
                            'desc'     => __( 'This allows you to set a pre-styled menu. This will override all your current styles.', '_supermenu_' ),
                            'options'  => array(
                                '1' => array(
                                    'alt'     => 'Dark',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/dark.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#272727',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#cccccc',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#48e0a4'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#272727',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#cccccc',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#48e0a4'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#272727',
                                        		'hover' 			=> '#1D1D1D',
                                        		'active' 			=> '#1D1D1D'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 4
                                    )
                                ),
                                '2' => array(
                                    'alt'     => 'Blue',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/blue.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#0099CC',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#006D91',
                                        		'active' 			=> '#006D91'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#0099CC',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#006d91',
                                        		'active' 			=> '#006d91'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#0099CC',
                                        		'hover' 			=> '#0099CC',
                                        		'active' 			=> '#0099CC'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 0
                                    )
                                ),
                                '3' => array(
                                    'alt'     => 'Dark Blue',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/dark-blue.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#485053',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#cccccc',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#ffffff'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#343434',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#cccccc',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#48e0a4'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#272727',
                                        		'hover' 			=> '#1D1D1D',
                                        		'active' 			=> '#1D1D1D'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 4
                                    )
                                ),
                                '4' => array(
                                    'alt'     => 'Pink',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/pink.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#ED6E91',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#ED6E91',
                                        		'active' 			=> '#ED6E91'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#ffffff',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#ED6E91',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#ffffff'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#ED6E91',
                                        		'active' 			=> '#ED6E91'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 4
                                    )
                                ),
                                '5' => array(
                                    'alt'     => 'Green',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/green.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#00B16A',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#00B16A',
                                        		'active' 			=> '#00B16A'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#ffffff',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#00B16A',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#ffffff'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#00B16A',
                                        		'active' 			=> '#00B16A'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 4
                                    )
                                ),
                                '6' => array(
                                    'alt'     => 'Purple',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/purple.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#A051D3',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#A051D3',
                                        		'active' 			=> '#A051D3'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#ffffff',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#A051D3',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#ffffff'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#A051D3',
                                        		'active' 			=> '#A051D3'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 4
                                    )
                                ),
                                '7' => array(
                                    'alt'     => 'Turq',
                                    'img'     => plugin_dir_url( __FILE__ ) . '../assets/img/presets/turq.png',
                                    'presets' => array(
                                        'sm-logo'      			=>
                                        	array( 
                                        		'url'		=> 'http://i.imgur.com/L4EffT9.png'
																						),
																				'sm-menu-bg' 				=>
																					array(
                                        		'color'			=> '#23AEA9',
                                        		'alpha' 				=> '1.0'
																						),
																				'sm-level-one-links' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#23AEA9',
                                        		'active' 			=> '#23AEA9'
																						),
																				'sm-dropdown-bg' =>
                                        	array(
                                        		'color'				=> '#ffffff',
                                        		'alpha' 			=> '1.0'
																						),
																				'sm-level-two-links' =>
                                        	array(
                                        		'regular'			=> '#23AEA9',
                                        		'hover' 			=> '#ffffff',
                                        		'active' 			=> '#ffffff'
																						),
																				'sm-level-two-bg' =>
                                        	array(
                                        		'regular'			=> '#ffffff',
                                        		'hover' 			=> '#23AEA9',
                                        		'active' 			=> '#23AEA9'
																						),
																				'sm-drop-border' =>
                                        	array(
                                        		'border-color'  => '#E2E2E2',
																						'border-style'  => 'solid',
                                        		'border-top'	  => '0px',
                                        		'border-right'  => '0px',
                                        		'border-bottom' => '0px',
                                        		'border-left' 	=> '0px'
																						),
																				'sm-drop-border-radius' => 4
                                    )
                                )
                            ),
                        ),
	               ),
            );
						
            /******************************************
						*TOP MENU SETTINGS
						******************************************/
            $this->sections[] = array(
                'title'     => __('Topmenu Configs', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-cogs',
                'fields'    => array(
                		array(
                            'id'       => 'sm-active-menu',
                            'type'     => 'select',
                            'data'     => 'menu_location',
                            'title'    => __( 'Activate Supermenu for', '_supermenu_' ),
                            'subtitle' => __( 'Choose the menu location to set Supermenu on.', '_supermenu_' ),
                            'desc'     => __( 'Ideally, the main navigation for your theme should be selected. Your menu works without configuring this? Supermenu picked up the first navigation menu it found and activated on its own.', '_supermenu_' ),
                    ),
                    
                    array(
                        'id'                => 'sm-container',
                        'type'              => 'dimensions',
                        'units'             => 'px',    // You can specify a unit value. Possible: px, em, %
                        'units_extended'    => 'true',  // Allow users to select any type of unit
                        'title'             => __('Menu Bar Size', '_supermenu_'),
                        'subtitle'          => __('', '_supermenu_'),
                        'desc'              => __('The height should ideally be 20px more than the logo height. So if your logo height is 50px, the menu height should be 70px.', '_supermenu_'),
                        'default'           => array(
                            'height'		=> 100,
                            'width'			=> 1170
                        )
                    ),
                    array(
                        'id'            => 'sm-menu-breakpoint',
                        'type'          => 'slider',
                        'title'         => __('Menu Breakpoint', '_supermenu_'),
                        'subtitle'      => __('Screen width at which your menu would turn into mobile menu.', '_supermenu_'),
                        'desc'          => __('', '_supermenu_'),
                        'default'       => 786,
                        'min'           => 480,
                        'step'          => 3,
                        'max'           => 1400,
                        'display_value' => 'text'
                    ),
                    array(
	                        'id'        => 'sm-menu-style',
	                        'type'      => 'select',
	                        'title'     => __('Choose Menu Layout (Beta)', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('Inline: Logo and Menu items are both displayed in a row.<br>Stacked: Logo is displayed on the top of the menu items.', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'style_1' => 'Inline (Style 1)', 
	                            'style_2' => 'Stacked (Style 2)'
	                        ),
	                        'default'   => 'style_1'
	                   ),
                    array(
                        'id'        => 'sm-menu-shadow',
                        'type'      => 'switch',
                        'title'     => __('Enable Top Menu Shadow', '_supermenu_'),
                        'subtitle'  => __('Subtle shadow under the menu bar.', '_supermenu_'),
                        'default'   => true,
                    ),
                    array(
                        'id'        => 'sm-menu-shadow-size',
                        'type'      => 'button_set',
                        'title'     => __('Menu Shadow Size', 'redux-framework-demo'),
                        'subtitle'  => __('If your menu has a light color background, choose the Dark option from below and vice versa. Just to make sure the menu toggle icon is visible.', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'options'   => array(
                        		'small-shadow-btm' 					=> 'Small Shadow',
                            'medium-shadow-btm' 				=> 'Medium Shadow',
                            'large-shadow-btm'					=> 'Large Shadow'
                        ), 
                        'default'   => 'small-shadow-btm',
                        'required'  		=> array('sm-menu-shadow', '=', true)
                    ),
                    array(
                        'id'        => 'sm-drop-shadow',
                        'type'      => 'switch',
                        'title'     => __('Enable Dropdown Shadow', '_supermenu_'),
                        'subtitle'  => __('Shadow under dropdown.', '_supermenu_'),
                        'default'   => false,
                    ), 
                    array(
                        'id'        => 'sm-container-type',
                        'type'      => 'switch',
                        'title'     => __('Full Width Menu', '_supermenu_'),
                        'subtitle'  => __('Will remove the inner container making the menu full width.', '_supermenu_'),
                        'default'   => false,
                    ),
                ),
            ); 
            
            /******************************************
						*TOP MENU LOGO
						******************************************/
            $this->sections[] = array(
                'title'     => __('Top Menu Logo', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-cogs',
                'subsection'=> true,
                'fields'    => array(
                						array(
                        'id'        => 'sm-tm-logo-type',
                        'type'      => 'button_set',
                        'title'     => __('Topmenu Logo Type', 'redux-framework-demo'),
                        'subtitle'  => __('', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'options'   => array(
                        		'text-logo' 					=> 'Text Logo',
                            'img-logo' 						=> 'Image Logo',
                        ), 
                        'default'   => 'img-logo',
                    ),
                		array(
                        'id'        => 'sm-logo',
                        'type'      => 'media',
                        'title'     => __('Logo', '_supermenu_'),
                        'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc'      => __('Our logo was 225x30px for your reference.', '_supermenu_'),
                        'subtitle'  => __('Upload a logo which shall replace the default text logo.', '_supermenu_'),
                        'default'  => array(
										        'url'		=>	plugin_dir_url( __FILE__ ) . '../assets/img/supermenu.png'
										    ),
										    'required'  		=> array('sm-tm-logo-type', '=', 'img-logo')
                    ),
                    array(
                        'id'            => 'sm-logo-height',
                        'type'          => 'slider',
                        'title'         => __('Logo Height', '_supermenu_'),
                        'subtitle'      => __('Make sure to adjust the menu container height below this too.', '_supermenu_'),
                        'desc'          => __('This wont resize your logo. It will just not let the logo go above the height you specify. In other words, add a max-height to the logo.', '_supermenu_'),
                        'default'       => 70,
                        'min'           => 10,
                        'step'          => 1,
                        'max'           => 300,
                        'display_value' => 'text',
                        'required'  		=> array('sm-tm-logo-type', '=', 'img-logo')
                    ),
                    array(
										    'id'       => 'sm-text-logo',
										    'type'     => 'text',
										    'title'    => __('Enter your Logo text', 'redux-framework-demo'),
										    'subtitle' => __('', 'redux-framework-demo'),
										    'desc'     => __('', 'redux-framework-demo'),
										    'validate' => 'no_html',
										    'msg'      => 'Error',
										    'default'  => 'Supermenu',
										    'required'  		=> array('sm-tm-logo-type', '=', 'text-logo')
										),
										array(
                        'id'            => 'sm-tm-text-logo-typography',
                        'type'          => 'typography',
                        'title'         => __('Logo Typography', '_supermenu_'),
                        'google'        => true,
                        'font-backup'   => true,
                        'text-align'		=> false,
                        'letter-spacing'=> true,
                        'line-height'		=> false,
                        'text-transform'=> true,
                        'color'         => false,
                        'all_styles'    => true,
                        'units'         => 'px',
                        'subtitle'      => __('', '_supermenu_'),
                        'default'       => array(
                        		'color'					=> '',
                            'font-weight'    => '700',
                            'font-family'   => 'Raleway',
                            'text-transform'=> 'uppercase',
                            'letter-spacing'=> '3px',
                            'google'        => true,
                            'font-size'     => '24px'),
                        'preview' => array('text' => 'Supermenu'),
                        'required'  		=> array('sm-tm-logo-type', '=', 'text-logo')
                    ),
                    array(
                        'id'        => 'sm-tm-text-logo-color',
                        'type'      => 'link_color',
                        'title'     => __('Logo Color', '_supermenu_'),
                        'subtitle'  => __('', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'active'    => false,
                        'default'   => array(
                            'regular'   => '#323a45',
                            'hover'     => '#323a45',
                        ),
                        'required'  		=> array('sm-tm-logo-type', '=', 'text-logo')
                    ),
                    array(
                        'id'       => 'sm-tm-logo-border',
                        'type'     => 'border',
                        'title'    => __( 'Text Logo Border', '_supermenu_' ),
                        'subtitle' => __( 'Default: 0', '_supermenu_' ),
                        'all'			 => false,
                        // An array of CSS selectors to apply this font style to
                        'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                        'default'  => array(
                            'border-color'  => '#323a45',
                            'border-style'  => 'solid',
                            'border-top'    => '4px',
                            'border-right'  => '4px',
                            'border-bottom' => '4px',
                            'border-left'   => '4px'
                        ),
                        'required'  		=> array('sm-tm-logo-type', '=', 'text-logo')
                    ),
                    array(
                        'id'       => 'sm-tm-logo-border-hover',
                        'type'     => 'border',
                        'title'    => __( 'Text Logo Border on Hover', '_supermenu_' ),
                        'subtitle' => __( 'Default: 0', '_supermenu_' ),
                        'all'			 => false,
                        // An array of CSS selectors to apply this font style to
                        'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                        'default'  => array(
                            'border-color'  => '#ff3366',
                            'border-style'  => 'solid',
                            'border-top'    => '4px',
                            'border-right'  => '4px',
                            'border-bottom' => '4px',
                            'border-left'   => '4px'
                        ),
                        'required'  		=> array('sm-tm-logo-type', '=', 'text-logo')
                    ),
                ),
             );
            /******************************************
						*TOP MENU STYLING
						******************************************/
            $this->sections[] = array(
                'title'     => __('Top Menu Styling', '_supermenu_'),
                'desc'      => __('Menu Styling here', '_supermenu_'),
                'icon'      => 'el-icon-eye-open',
                'subsection'=> true,
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(

                    array(
                            'id'       => 'sm-menu-bg',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Topmenu Background Color', '_supermenu_' ),
                            'subtitle' => __( 'Background Color of your Topmenu', '_supermenu_' ),
                            'desc'     => __('', '_supermenu_'),
                            'default'  => array( 'color' => '#fff', 'alpha' => '1.0' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'options'       => array(
												        'show_buttons'              => false
												    ), 
                     ),
                     
                    array(
                            'id'       => 'sm-menu-border',
                            'type'     => 'border',
                            'title'    => __( 'Topmenu Border Option', '_supermenu_' ),
                            'subtitle' => __( 'Default: 0', '_supermenu_' ),
                            'all'			 => false,
                            'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                            'default'  => array(
                                'border-color'  => '#d3d3d3',
                                'border-style'  => 'solid',
                                'border-top'    => '0px',
                                'border-right'  => '0px',
                                'border-bottom' => '0px',
                                'border-left'   => '0px'
                            )
                        ),
                    array(
                        'id'            => 'sm-menu-border-radius',
                        'type'          => 'slider',
                        'title'         => __('Topmenu Border Radius', '_supermenu_'),
                        'subtitle'      => __('in px', '_supermenu_'),
                        'desc'          => __('Border Radius for Menu Container', '_supermenu_'),
                        'default'       => 0,
                        'min'           => 0,
                        'step'          => 1,
                        'max'           => 100,
                        'display_value' => 'text'
                    ),
                    
                    array(
                        'id'        => 'sm-level-one-links',
                        'type'      => 'link_color',
                        'title'     => __('Topmenu First Level Links Color', '_supermenu_'),
                        'subtitle'  => __('Menu links Color Configuration', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'default'   => array(
                            'regular'   => '#4E5B6C',
                            'hover'     => '#bfbfbf',
                            'active'    => '#bfbfbf',
                        )
                    ),
                    array(
                        'id'            => 'sm-level-one-typography',
                        'type'          => 'typography',
                        'title'         => __('Topmenu First Level Typography', '_supermenu_'),
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => true,    // Select a backup non-google font in addition to a google font
                        'text-align'		=> false,
                        'letter-spacing'=> true,  // Defaults to false
                        'text-transform'=> true,
                        'line-height'		=> false,
                        'color'         => false,
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Menu Items Typography.', '_supermenu_'),
                        'default'       => array(
                            'font-weight'    => '700',
                            'font-family'   => 'Montserrat',
                            'text-transform'=> 'uppercase',
                            'letter-spacing'=> '1px',
                            'google'        => true,
                            'font-size'     => '11px'),
                        'preview' => array('text' => 'Grumpy wizards make toxic brew for the evil Queen and Jack.'),
                    ),
                    array(
	                        'id'        => 'sm-top-menu-link-hover',
	                        'type'      => 'select',
	                        'title'     => __('Choose Top Link Hover Effect', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        'options'   => array(
	                        		'none'	=> 'Disabled',
	                            '1' 		=> '1', 
	                            '2' 		=> '2',
	                            '3'			=> '3',
	                            '4'			=> '4',
	                            '5'			=> '5'
	                        ),
	                        'default'   => 'none'
	                    ),
                    array(
                            'id'       => 'sm-dropdown-bg',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Dropdown Background', '_supermenu_' ),
                            'subtitle' => __( 'Background Color of the Dropdown Menu', '_supermenu_' ),
                            'default'  => array( 'color' => '#323a45', 'alpha' => '1.0' ),
                            //'output'   => array( 'body' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'options'       => array(
												        'show_buttons'              => false
												    ),
                        ),
                    
                    array(
                        'id'            => 'sm-drop-border-radius',
                        'type'          => 'slider',
                        'title'         => __('Dropdown Border Radius', '_supermenu_'),
                        'subtitle'      => __('in px', '_supermenu_'),
                        'desc'          => __('Border Radius for Menu Container', '_supermenu_'),
                        'default'       => 2,
                        'min'           => 0,
                        'step'          => 1,
                        'max'           => 100,
                        'display_value' => 'text'
                    ),
                    array(
                        'id'        => 'sm-level-two-links',
                        'type'      => 'link_color',
                        'title'     => __('Dropdown Links Color Option', '_supermenu_'),
                        'subtitle'  => __('', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'default'   => array(
                            'regular'   => '#BABABA',
                            'hover'     => '#ffffff',
                            'active'    => '#ffffff',
                        )
                    ),
                    array(
                            'id'       => 'sm-drop-border',
                            'type'     => 'border',
                            'title'    => __( 'Dropdown Border Option', '_supermenu_' ),
                            'subtitle' => __( 'Default: 0', '_supermenu_' ),
                            'all'			 => false,
                            // An array of CSS selectors to apply this font style to
                            'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                            'default'  => array(
                                'border-color'  => '#ff3366',
                                'border-style'  => 'solid',
                                'border-top'    => '0px',
                                'border-right'  => '0px',
                                'border-bottom' => '0px',
                                'border-left'   => '0px'
                            )
                        ),
                    array(
                        'id'            => 'sm-level-two-typography',
                        'type'          => 'typography',
                        'title'         => __('Dropdown Typography', '_supermenu_'),
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => true,    // Select a backup non-google font in addition to a google font
                        'letter-spacing'=> true,  // Defaults to false
                        'color'         => false,
                        'text-transform'=> true,
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Typography option with each property can be called individually.', '_supermenu_'),
                        'default'       => array(
                            'font-weight'    => '700',
                            'font-family'   => 'Montserrat',
                            'text-transform'=> 'uppercase',
                            'letter-spacing'=> '1px',
                            'google'        => true,
                            'text-align'		=> 'left',
                            'font-size'     => '11px',
                            'line-height'   => '20px'),
                        'preview' => array('text' => 'Grumpy wizards make toxic brew for the evil Queen and Jack.'),
                    ),
                    
                ),
            ); 
                         
            /******************************************
						*SUPERSIDE SETTINGS
						******************************************/      
						$this->sections[] = array(
                'title'     => __('Superside Configs', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-chevron-left',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                		array(
                        'id'        => 'sm-superside-layout',
                        'type'      => 'button_set',
                        'title'     => __('Choose Superside\'s Layout', 'redux-framework-demo'),
                        'subtitle'  => __('', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'options'   => array(
                        		'superside-is-aside' 					=> 'Aside',
                            'superside-is-fullwidth' 					=> 'Full Width / Full Screen'
                        ), 
                        'default'   => 'superside-is-aside',
                    ),
                    array(
                        'id'        => 'sm-superside-aside-out',
                        'type'      => 'button_set',
                        'title'     => __('Choose Superside\'s Layout', 'redux-framework-demo'),
                        'subtitle'  => __('', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'options'   => array(
                        		'superside-is-aside--left' 				=> 'Out from Left',
                            'superside-is-aside--right' 			=> 'Out from Right'
                        ), 
                        'default'   => 'superside-is-aside--right',
                        'required'  		=> array('sm-superside-layout', '=', 'superside-is-aside')
                    ),
                    array(
	                        'id'        => 'sm-fixed-superside-icon',
	                        'type'      => 'switch',
	                        'title'     => __('Fixed Superside Icon?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => false,
	                  ),
	                  array(
                        'id'            => 'sm-ss-separator-height',
                        'type'          => 'slider',
                        'title'         => __('Elements Separators Height', '_supermenu_'),
                        'subtitle'      => __('', '_supermenu_'),
                        'desc'          => __('', '_supermenu_'),
                        'default'       => 40,
                        'min'           => 2,
                        'step'          => 2,
                        'max'           => 100,
                        'display_value' => 'text',
                    ),
                    array(
                        'id'       => 'sm-ss-separator-bg',
                        'type'     => 'color_rgba',
                        'title'    => __( 'Elements Separators Background', '_supermenu_' ),
                        'subtitle' => __( '', '_supermenu_' ),
                        'default'  => array( 'color' => '#343434', 'alpha' => '1.0' ),
                        'mode'     => 'background',
                        'validate' => 'colorrgba',
                        'options'       => array(
										        'show_buttons'              => false
										    ),
                    ),
	                  array(
                        'id'            => 'sm-ss-separator-line-width',
                        'type'          => 'slider',
                        'title'         => __('Logo Width', '_supermenu_'),
                        'subtitle'      => __('Make sure to adjust the menu container height below this too.', '_supermenu_'),
                        'desc'          => __('This wont resize your logo. It will just not let the logo go above the height you specify. In other words, add a max-height to the logo.', '_supermenu_'),
                        'default'       => 1,
                        'min'           => 0,
                        'step'          => 1,
                        'max'           => 10,
                        'display_value' => 'text',
                    ),
                    array(
	                        'id'        => 'sm-superside-logo-align',
	                        'type'      => 'select',
	                        'title'     => __('Choose Superside Logo Alignment', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'ss-logo--left' 			=> 'Left',
	                            'ss-logo--center' 		=> 'Center', 
	                            'ss-logo--right'			=> 'Right'
	                        ),
	                        'default'   => 'ss-logo--center',
	                    ),
                    array(
	                        'id'        => 'sm-superside-menu-items-align',
	                        'type'      => 'select',
	                        'title'     => __('Choose Superside Menu Items Alignment', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'ss-items--left' 			=> 'Left',
	                            'ss-items--center' 		=> 'Center', 
	                            'ss-items--right'			=> 'Right'
	                        ),
	                        'default'   => 'ss-items--left',
	                    ),
	                  
	                   array(
	                        'id'        => 'sm-superside-copyrights-align',
	                        'type'      => 'select',
	                        'title'     => __('Choose Superside Copyrights Text Alignment', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'ss-copy--left' 			=> 'Left',
	                            'ss-copy--center' 		=> 'Center', 
	                            'ss-copy--right'			=> 'Right'
	                        ),
	                        'default'   => 'ss-copy--center',
	                    ),
                    array(
                        'id'        => 'sm-superside-copyrights',
                        'type'      => 'textarea',
                        'title'     => __('Copyrights message in Superside menu?', 'redux-framework-demo'),
                        'subtitle'  => __('HTML Allowed', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'validate'  => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                        'default'   => 'COPYRIGHTS',
                    ),
                ),
            ); 
            /******************************************
						*SUPERSIDE LOGO
						******************************************/
            $this->sections[] = array(
                'title'     => __('Superside Logo', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-cogs',
                'subsection'=> true,
                'fields'    => array(
                		array(
                        'id'        => 'sm-ss-logo-type',
                        'type'      => 'button_set',
                        'title'     => __('Superside Menu Logo Type', 'redux-framework-demo'),
                        'subtitle'  => __('', 'redux-framework-demo'),
                        'desc'      => __('', 'redux-framework-demo'),
                        'options'   => array(
                        		'text-logo' 					=> 'Text Logo',
                            'img-logo' 						=> 'Image Logo',
                        ), 
                        'default'   => 'text-logo',
                    ),
                    array(
                        'id'        => 'sm-superside-logo',
                        'type'      => 'media',
                        'title'     => __('Logo Image', '_supermenu_'),
                        'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc'      => __('Our logo was 225x30px for your reference.', '_supermenu_'),
                        'subtitle'  => __('Upload a logo which shall replace the default logo.', '_supermenu_'),
                        'default'  => array(
										        'url'		=>plugin_dir_url( __FILE__ ) . '../assets/img/supermenu-white.png'
										    ),
										    'required'  		=> array('sm-ss-logo-type', '=', 'img-logo')
                    ),
                    array(
                        'id'            => 'sm-ss-logo-width',
                        'type'          => 'slider',
                        'title'         => __('Logo Width', '_supermenu_'),
                        'subtitle'      => __('Make sure to adjust the menu container height below this too.', '_supermenu_'),
                        'desc'          => __('This wont resize your logo. It will just not let the logo go above the height you specify. In other words, add a max-height to the logo.', '_supermenu_'),
                        'default'       => 80,
                        'min'           => 1,
                        'step'          => 1,
                        'max'           => 100,
                        'display_value' => 'text',
                        'required'  		=> array('sm-ss-logo-type', '=', 'img-logo')
                    ),
                    array(
										    'id'       => 'sm-ss-text-logo',
										    'type'     => 'text',
										    'title'    => __('Enter your Logo text', 'redux-framework-demo'),
										    'subtitle' => __('', 'redux-framework-demo'),
										    'desc'     => __('', 'redux-framework-demo'),
										    'validate' => 'no_html',
										    'msg'      => 'Error',
										    'default'  => 'Supermenu',
										    'required'  		=> array('sm-ss-logo-type', '=', 'text-logo')
										),
										array(
                        'id'            => 'sm-ss-text-logo-typography',
                        'type'          => 'typography',
                        'title'         => __('Logo Typography', '_supermenu_'),
                        'google'        => true,
                        'font-backup'   => true,
                        'text-align'		=> false,
                        'letter-spacing'=> true,
                        'line-height'		=> false,
                        'text-transform'=> true,
                        'color'         => false,
                        'all_styles'    => true,
                        'units'         => 'px',
                        'subtitle'      => __('', '_supermenu_'),
                        'default'       => array(
                        		'color'					=> '',
                            'font-weight'    => '700',
                            'font-family'   => 'Montserrat',
                            'text-transform'=> 'uppercase',
                            'letter-spacing'=> '3px',
                            'google'        => true,
                            'font-size'     => '14px'),
                        'preview' => array('text' => 'Supermenu'),
                        'required'  		=> array('sm-ss-logo-type', '=', 'text-logo')
                    ),
                    array(
                        'id'        => 'sm-ss-text-logo-color',
                        'type'      => 'link_color',
                        'title'     => __('Logo Color', '_supermenu_'),
                        'subtitle'  => __('', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'active'    => false,
                        'default'   => array(
                            'regular'   => '#565656',
                            'hover'     => '#ffffff',
                        ),
                        'required'  		=> array('sm-ss-logo-type', '=', 'text-logo')
                    ),
                    array(
                        'id'       => 'sm-ss-logo-border',
                        'type'     => 'border',
                        'title'    => __( 'Text Logo Border', '_supermenu_' ),
                        'subtitle' => __( 'Default: 0', '_supermenu_' ),
                        'all'			 => false,
                        // An array of CSS selectors to apply this font style to
                        'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                        'default'  => array(
                            'border-color'  => '#565656',
                            'border-style'  => 'solid',
                            'border-top'    => '2px',
                            'border-right'  => '2px',
                            'border-bottom' => '2px',
                            'border-left'   => '2px'
                        ),
                        'required'  		=> array('sm-ss-logo-type', '=', 'text-logo')
                    ),
                    array(
                        'id'       => 'sm-ss-logo-border-hover',
                        'type'     => 'border',
                        'title'    => __( 'Text Logo Border on Hover', '_supermenu_' ),
                        'subtitle' => __( 'Default: 0', '_supermenu_' ),
                        'all'			 => false,
                        // An array of CSS selectors to apply this font style to
                        'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                        'default'  => array(
                            'border-color'  => '#ffffff',
                            'border-style'  => 'solid',
                            'border-top'    => '2px',
                            'border-right'  => '2px',
                            'border-bottom' => '2px',
                            'border-left'   => '2px'
                        ),
                        'required'  		=> array('sm-ss-logo-type', '=', 'text-logo')
                    ),
                ),
             );
            /******************************************
						*SUPERSIDE STYLING
						******************************************/      
						$this->sections[] = array(
                'title'     => __('Superside Styling', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-eye-open',
                'subsection'=> true,
                'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                
                	
                		array(
                            'id'       => 'sm-superside-bg',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Superside Background', '_supermenu_' ),
                            'subtitle' => __( 'Background Color of the Superside Menu', '_supermenu_' ),
                            'default'  => array( 'color' => '#1c1c1c', 'alpha' => '1.0' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'options'       => array(
												        'show_buttons'              => false
												    ),
                        ),
                        
                    array(
                            'id'       => 'sm-superside-body-overlay',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Body Overlay Color when Superside is open', '_supermenu_' ),
                            'subtitle' => __( 'Background Color of the Superside Menu', '_supermenu_' ),
                            'default'  => array( 'color' => '#fff', 'alpha' => '0' ),
                            //'output'   => array( 'body' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'options'       => array(
												        'show_buttons'              => false
												    ),
                        ),
                		array(
                        'id'            => 'sm-superside-typography',
                        'type'          => 'typography',
                        'title'         => __('Superside Typography', '_supermenu_'),
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => true,    // Select a backup non-google font in addition to a google font
                        'text-align'		=> false,
                        'letter-spacing'=> true,  // Defaults to false
                        'text-transform'=> true,
                        'color'         => false,
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Menu Items Typography.', '_supermenu_'),
                        'default'       => array(
                            'font-weight'    => '700',
                            'font-family'   => 'Montserrat',
                            'text-transform'=> 'uppercase',
                            'letter-spacing'=> '2px',
                            'google'        => true,
                            'font-size'     => '11px',
                            'line-height'   => '40px'),
                        'preview' => array('text' => 'Grumpy wizards make toxic brew for the evil Queen and Jack.'),
                    ),
                    array(
                        'id'        => 'sm-superside-links',
                        'type'      => 'link_color',
                        'title'     => __('Superside Menu Links Color Option', '_supermenu_'),
                        'subtitle'  => __('Menu links Color Configuration', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'default'   => array(
                            'regular'   => '#565656',
                            'hover'     => '#ffffff',
                            'active'    => '#ffffff',
                        )
                    ),
                    array(
                            'id'       => 'sm-superside-link-hvr-bg',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Link Hover Background', '_supermenu_' ),
                            'subtitle' => __( '', '_supermenu_' ),
                            'default'  => array( 'color' => '#0f0f0f', 'alpha' => '1.0' ),
                            //'output'   => array( 'body' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'options'       => array(
												        'show_buttons'              => false
												    ),
                        ),
                ),
            ); 
            
						/******************************************
						*MENU STATES
						******************************************/      
						$this->sections[] = array(
                'title'     => __('Menu States', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-adjust-alt',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                
                		array(
	                        'id'        => 'sm-visible-load',
	                        'type'      => 'switch',
	                        'title'     => __('Top Menu Visible on Page Load?', '_supermenu_'),
	                        'subtitle'  => __('If disabled, top menu will be replaced by a toggle button, clicking on which would show Top Menu.', '_supermenu_'),
	                        'on'				=> 'Yes',
	                        'off'				=> 'No',
	                        'default'   => true,
	                  ),
	                  array(
                        'id'        => 'sm-fixed-menu',
                        'type'      => 'switch',
                        'title'     => __('Fixed Menu', '_supermenu_'),
                        'subtitle'  => __('If enabled, menu will stick to the top of page.', '_supermenu_'),
                        'default'   => true,
                    ),
                    array(
                        'id'        => 'sm-menu-configure-padding',
                        'type'      => 'button_set',
                        'title'     => __('Hey! Configure Padding', 'redux-framework-demo'),
                        'subtitle'  => __('Don\'t need that animation looking effect? Configure padding manually please.', 'redux-framework-demo'),
                        'desc'      => __('Automatic: Supermenu calculates the menu\'s height and adds padding automatically.<br>Manual: You need to find the menu\'s height and add padding here.', 'redux-framework-demo'),
                        'options'   => array(
                        		'automatic' 					=> 'Automatic',
                            'manual' 							=> 'Manual'
                        ), 
                        'default'   => 'automatic',
                        'required'  		=> array('sm-fixed-menu', '=', true)
                    ),
                    array(
                        'id'            => 'sm-menu-set-padding-amount',
                        'type'          => 'slider',
                        'title'         => __('Set top padding required for fixed menu.', '_supermenu_'),
                        'subtitle'      => __('', '_supermenu_'),
                        'desc'          => __('', '_supermenu_'),
                        'default'       => 90,
                        'min'           => 0,
                        'step'          => 1,
                        'max'           => 1000,
                        'display_value' => 'text',
                        'required'  		=> array('sm-menu-configure-padding', '=', 'manual')
                    ),
                    array(
                        'id'            => 'sm-menu-effect-triggerpoint',
                        'type'          => 'slider',
                        'title'         => __('ETP -or- Effect Trigger Point', '_supermenu_'),
                        'subtitle'      => __('When a user reaches a scrolling distance of the amount you set here, the effects like Color change, menu scalling would trigger.', '_supermenu_'),
                        'desc'          => __('Scroll Amount for trigger menu effects', '_supermenu_'),
                        'default'       => 100,
                        'min'           => 1,
                        'step'          => 1,
                        'max'           => 5000,
                        'display_value' => 'text',
                        'required'  		=> array('sm-fixed-menu', '=', true)
                    ),
                    array(
	                        'id'        => 'sm-after-fixed',
	                        'type'      => 'select',
	                        'title'     => __('Choose Menu Style', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'fixed_basic' 		=> 'The usual fixed menu', 
	                            'visible_up' 			=> 'Visible when scrolling up',
	                            'hide_then_show'	=> 'Not Fixed then fixed at Effect Trigger Point.'
	                        ),
	                        'default'   => 'fixed_basic',
	                        'required'  		=> array('sm-fixed-menu', '=', true)
	                    ),
	                    
	                   array(
	                        'id'        => 'sm-change-menu-color',
	                        'type'      => 'switch',
	                        'title'     => __('Change Menu Styles at ETP?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'default'   => false,
	                        'required'  		=> array('sm-fixed-menu', '=', true)
	                        
	                    ),
	                   array(
                        'id'        => 'sm-logo-alt',
                        'type'      => 'media',
                        'title'     => __('Change Logo at ETP', '_supermenu_'),
                        'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc'      => __('Alternate Logo', '_supermenu_'),
                        'subtitle'  => __('Want a different logo on after Effect triggerpoint. Upload it here.', '_supermenu_'),
                        'default'  => array(
										        'url'=>		plugin_dir_url( __FILE__ ) . '../assets/img/supermenu-white.png'
										    ),
										    'required'  		=> array(
										    		array('sm-change-menu-color', '=', true),
										    		array('sm-tm-logo-type', '=', 'img-logo')
												)
										 ),
										 array(
                        'id'        => 'sm-tm-text-logo-color-alt',
                        'type'      => 'link_color',
                        'title'     => __('Logo Color at ETP', '_supermenu_'),
                        'subtitle'  => __('', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'active'    => false,
                        'default'   => array(
                            'regular'   => '#565656',
                            'hover'     => '#ffffff',
                        ),
                        'required'  		=> array(
										    		array('sm-change-menu-color', '=', true),
										    		array('sm-tm-logo-type', '=', 'text-logo')
												)
                    ),
                    array(
                        'id'       => 'sm-tm-logo-border-alt',
                        'type'     => 'border',
                        'title'    => __( 'Text Logo Border at ETP', '_supermenu_' ),
                        'subtitle' => __( 'Default: 0', '_supermenu_' ),
                        'all'			 => false,
                        // An array of CSS selectors to apply this font style to
                        'desc'     => __( 'Arrows represent border directions. So the top arrow would control the border-top and so on.', '_supermenu_' ),
                        'default'  => array(
                            'border-color'  => '#565656',
                            'border-style'  => 'solid',
                            'border-top'    => '2px',
                            'border-right'  => '2px',
                            'border-bottom' => '2px',
                            'border-left'   => '2px'
                        ),
                        'required'  		=> array(
										    		array('sm-change-menu-color', '=', true),
										    		array('sm-tm-logo-type', '=', 'text-logo')
												)
                    ),
	                   array(
                            'id'       => 'sm-change-menu-bg',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Menu Background at ETP', '_supermenu_' ),
                            'subtitle' => __( '', '_supermenu_' ),
                            'desc'     => __('', '_supermenu_'),
                            'default'  => array( 'color' => '#fff', 'alpha' => '0.3' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'required'  		=> array('sm-change-menu-color', '=', true),
                            'options'       => array(
												        'show_buttons'              => false
												    ),
                     ),
                     array(
                            'id'       => 'sm-change-dropdown-bg',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Dropdown Background Color at ETP', '_supermenu_' ),
                            'subtitle' => __( '', '_supermenu_' ),
                            'default'  => array( 'color' => '#fff', 'alpha' => '1.0' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'required'  		=> array('sm-change-menu-color', '=', true),
                            'options'       => array(
												        'show_buttons'              => false
												    ),
                    ),
                     array(
                        'id'        => 'sm-change-level-one-links',
                        'type'      => 'link_color',
                        'title'     => __('First Level Link Color at ETP', '_supermenu_'),
                        'subtitle'  => __('Level 1 links Color Configuration', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'default'   => array(
                            'regular'   => '#9B9898',
                            'hover'     => '#ff3366',
                            'active'    => '#ff3366',
                        ),
                        'required'  		=> array('sm-change-menu-color', '=', true)
                    ),
                    array(
                        'id'        => 'sm-change-level-two-links',
                        'type'      => 'link_color',
                        'title'     => __('Dropdown Link Color at ETP', '_supermenu_'),
                        'subtitle'  => __('Dropdown links Color Configuration', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'default'   => array(
                            'regular'   => '#9B9898',
                            'hover'     => '#ff3366',
                            'active'    => '#ff3366',
                        ),
                        'required'  		=> array('sm-change-menu-color', '=', true)
                    ),
				            array(
	                        'id'        => 'sm-change-menu-width',
	                        'type'      => 'switch',
	                        'title'     => __('Change Menu Width at ETP??', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'default'   => false,
	                        'required'  		=> array('sm-fixed-menu', '=', true)
	                    ),
	                    				array(
				                        'id'        => 'sm-new-menu-width',
				                        'type'      => 'select',
				                        'title'     => __('Change Menu width at ETP', 'redux-framework-demo'),
				                        'subtitle'  => __('', 'redux-framework-demo'),
				                        'desc'      => __('Inline: Logo and Menu items are both displayed in a row.<br>Stacked: Logo is displayed on the top of the menu items.', 'redux-framework-demo'),
				                        
				                        'options'   => array(
				                            'container_then_full_width' 			=> 'Container then full width', 
				                            'full_width_then_container' 			=> 'Full Width then Container'
				                        ),
				                        'default'   => 'container_then_full_width',
				                        'required'  		=> array('sm-change-menu-width', '=', true)
				              ),
				              array(
	                        'id'        => 'sm-change-menu-size',
	                        'type'      => 'switch',
	                        'title'     => __('Scale menu on scroll?', '_supermenu_'),
	                        'subtitle'  => __('', '_supermenu_'),
	                        'default'   => true,
	                    ),
                ),
            ); 

						/******************************************
						*ICON CONFIGS
						******************************************/ 
						$this->sections[] = array(
                'title'     => __('Icon Configs', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-tags',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                		
                		array(
	                        'id'        => 'sm-searchform-style',
	                        'type'      => 'select',
	                        'title'     => __('Choose Searchform Style', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'popup-rounded-search' 			=> 'Popup Rounded', 
	                            'popup-squared-search' 			=> 'Popup Squared'
	                        ),
	                        'default'   => 'popup-rounded-search'
	                    ),
	                    array(
	                        'id'        => 'sm-tm-tgl-icon-size',
	                        'type'      => 'select',
	                        'title'     => __('Topmenu Toggle Icon Size', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'tm-tgl-sm' 		=> 'Small',
	                            'tm-tgl-md' 		=> 'Medium', 
	                            'tm-tgl-lg'			=> 'Large'
	                        ),
	                        'default'   => 'tm-tgl-sm',
	                    ),
	                    array(
                        'id'        => 'sm-tm-tgl-icon-color',
                        'type'      => 'link_color',
                        'title'     => __('Topmenu Toggle Icon Color', '_supermenu_'),
                        'subtitle'  => __('', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'active'    => false,
                        'default'   => array(
                            'regular'   => '#323a45',
                            'hover'     => '#323a45',
                        ),
											),
	                    array(
	                        'id'        => 'sm-ss-tgl-icon-size',
	                        'type'      => 'select',
	                        'title'     => __('Superside Toggle Icon Size', 'redux-framework-demo'),
	                        'subtitle'  => __('', 'redux-framework-demo'),
	                        'desc'      => __('', 'redux-framework-demo'),
	                        
	                        //Must provide key => value pairs for select options
	                        'options'   => array(
	                            'ss-tgl-sm' 		=> 'Small',
	                            'ss-tgl-md' 		=> 'Medium', 
	                            'ss-tgl-lg'			=> 'Large'
	                        ),
	                        'default'   => 'ss-tgl-sm',
	                    ),
	                    array(
                        'id'        => 'sm-ss-tgl-icon-color',
                        'type'      => 'link_color',
                        'title'     => __('Superside Toggle Icon Color', '_supermenu_'),
                        'subtitle'  => __('', '_supermenu_'),
                        'desc'      => __('', '_supermenu_'),
                        'active'    => false,
                        'default'   => array(
                            'regular'   => '#323a45',
                            'hover'     => '#323a45',
                        ),
											),
	                    array(
                            'id'       => 'sm-searchform-overlay',
                            'type'     => 'color_rgba',
                            'title'    => __( 'Searchform Overlay', '_supermenu_' ),
                            'subtitle' => __( '', '_supermenu_' ),
                            'desc'     => __('', '_supermenu_'),
                            'default'  => array( 'color' => '#000', 'alpha' => '0.6' ),
                            'mode'     => 'background',
                            'validate' => 'colorrgba',
                            'options'       => array(
												        'show_buttons'              => false
												    ), 
                     ),
                     array(
                            'id'       => 'sm-social-icons-placeholder-field',
                            'type'     => 'text',
                            'title'    => __( 'SOCIAL ICONS (Placeholder Field)', 'redux-framework-demo' ),
                            'subtitle' => __( '<a target="_blank" href="http://boldblocks.com/support/supermenu/how-to-add-icon-to-menu-items/">HOW TO ADD SOCIAL ICONS</a>', 'redux-framework-demo' ),
                            'desc'     => __( 'Make the field blank to disable icon.', 'redux-framework-demo' ),
                            'validate' => 'url',
                            'default'  => '',
                     ),
                     
                ),
            );  
						
						/******************************************
						*ANIMATION SETTINGS
						******************************************/  
            $this->sections[] = array(
                'title'     => __('Animation Settings', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'icon'      => 'el-icon-magic',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                
                		array(
                            'id'       => 'sm-menu-animation',
                            'type'     => 'select',
                            'title'    => __( 'Menu Animation', '_supermenu_' ),
                            'subtitle' => __( 'Choose the animation effect for your menu.', '_supermenu_' ),
                            'desc'     => __( 'Remember, YOLO.', '_supermenu_' ),
                            //Must provide key => value pairs for select options
                            'options'  => array(
                                'noanim' => 'disabled',
                                'bounce' => 'bounce',
                                'bounceIn' => 'bounceIn',
                                'bounceInDown' => 'bounceInDown',
                                'bounceInLeft' => 'bounceInLeft',
                                'bounceInRight' => 'bounceInRight',
                                'bounceInUp' => 'bounceInUp',
                                'fadeIn' => 'fadeIn',
                                'fadeInDown' => 'fadeInDown',
                                'fadeInDownBig' => 'fadeInDownBig',
                                'fadeInLeft' => 'fadeInLeft',
                                'fadeInLeftBig' => 'fadeInLeftBig',
                                'fadeInRight' => 'fadeInRight',
                                'fadeInRightBig' => 'fadeInRightBig',
                                'fadeInUp' => 'fadeInUp',
                                'fadeInUpBig' => 'fadeInUpBig',
                                'flip' => 'flip',
                                'flipInX' => 'flipInX',
                                'flipInY' => 'flipInY',
                                'flipOutX' => 'flipOutX',
                                'flipOutY' => 'flipOutY',
                                'lightSpeedIn' => 'lightSpeedIn',
                                'rotateIn' => 'rotateIn',
                                'rotateInDownLeft' => 'rotateInDownLeft',
                                'rotateInDownRight' => 'rotateInDownRight',
                                'rotateInUpLeft' => 'rotateInUpLeft',
                                'rotateInUpRight' => 'rotateInUpRight',
                                'rollIn' => 'rollIn',
                                'zoomIn' => 'zoomIn',
                                'zoomInDown' => 'zoomInDown',
                                'zoomInLeft' => 'zoomInLeft',
                                'zoomInRight' => 'zoomInRight',
                                'zoomInUp' => 'zoomInUp'
                                
                            ),
                            'default'  => 'fadeIn'
                        ),
                        array(
                            'id'            => 'sm-menu-anim-dur',
                            'type'          => 'slider',
                            'title'         => __( 'Menu Animation Duration (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Seconds for which the animation would run.', '_supermenu_' ),
                            'desc'          => __( '', '_supermenu_' ),
                            'default'       => 1.0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'            => 'sm-menu-anim-delay',
                            'type'          => 'slider',
                            'title'         => __( 'Menu Animation Delay (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Animation Delay. Default: 0', '_supermenu_' ),
                            'desc'          => __( 'This is the interval after which the animation would trigger.', '_supermenu_' ),
                            'default'       => 0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'       => 'sm-logo-animation',
                            'type'     => 'select',
                            'title'    => __( 'Logo Animation', '_supermenu_' ),
                            'subtitle' => __( 'Choose the animation effect for your logo. Default: fadeIn', '_supermenu_' ),
                            'desc'     => __( '', '_supermenu_' ),
                            //Must provide key => value pairs for select options
                            'options'  => array(
                                'noanim' => 'disabled',
                                'bounce' => 'bounce',
                                'bounceIn' => 'bounceIn',
                                'bounceInDown' => 'bounceInDown',
                                'bounceInLeft' => 'bounceInLeft',
                                'bounceInRight' => 'bounceInRight',
                                'bounceInUp' => 'bounceInUp',
                                'fadeIn' => 'fadeIn',
                                'fadeInDown' => 'fadeInDown',
                                'fadeInDownBig' => 'fadeInDownBig',
                                'fadeInLeft' => 'fadeInLeft',
                                'fadeInLeftBig' => 'fadeInLeftBig',
                                'fadeInRight' => 'fadeInRight',
                                'fadeInRightBig' => 'fadeInRightBig',
                                'fadeInUp' => 'fadeInUp',
                                'fadeInUpBig' => 'fadeInUpBig',
                                'flip' => 'flip',
                                'flipInX' => 'flipInX',
                                'flipInY' => 'flipInY',
                                'flipOutX' => 'flipOutX',
                                'flipOutY' => 'flipOutY',
                                'lightSpeedIn' => 'lightSpeedIn',
                                'rotateIn' => 'rotateIn',
                                'rotateInDownLeft' => 'rotateInDownLeft',
                                'rotateInDownRight' => 'rotateInDownRight',
                                'rotateInUpLeft' => 'rotateInUpLeft',
                                'rotateInUpRight' => 'rotateInUpRight',
                                'rollIn' => 'rollIn',
                                'zoomIn' => 'zoomIn',
                                'zoomInDown' => 'zoomInDown',
                                'zoomInLeft' => 'zoomInLeft',
                                'zoomInRight' => 'zoomInRight',
                                'zoomInUp' => 'zoomInUp'
                                
                            ),
                            'default'  => 'noanim'
                        ),
                         array(
                            'id'            => 'sm-logo-anim-dur',
                            'type'          => 'slider',
                            'title'         => __( 'Logo Animation Duration (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Seconds for which the animation would run.', '_supermenu_' ),
                            'desc'          => __( '', '_supermenu_' ),
                            'default'       => 1.0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'            => 'sm-logo-anim-delay',
                            'type'          => 'slider',
                            'title'         => __( 'Menu Animation Delay (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Animation Delay. Default: 0.2', '_supermenu_' ),
                            'desc'          => __( 'This is the interval after which the animation would trigger.', '_supermenu_' ),
                            'default'       => 0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'       => 'sm-mitems-anim',
                            'type'     => 'select',
                            'title'    => __( 'Menu Items Animation', '_supermenu_' ),
                            'subtitle' => __( 'Choose the animation effect for your menu items.  *Still in BETA*', '_supermenu_' ),
                            'desc'     => __( '*Effects except fadeIn might compatibility issues with Mega Menu if enabled.*', '_supermenu_' ),
                            //Must provide key => value pairs for select options
                            'options'  => array(
                                'noanim' => 'disabled',
                                'bounce' => 'bounce',
                                'bounceIn' => 'bounceIn',
                                'bounceInDown' => 'bounceInDown',
                                'bounceInLeft' => 'bounceInLeft',
                                'bounceInRight' => 'bounceInRight',
                                'bounceInUp' => 'bounceInUp',
                                'fadeIn' => 'fadeIn',
                                'fadeInDown' => 'fadeInDown',
                                'fadeInDownBig' => 'fadeInDownBig',
                                'fadeInLeft' => 'fadeInLeft',
                                'fadeInLeftBig' => 'fadeInLeftBig',
                                'fadeInRight' => 'fadeInRight',
                                'fadeInRightBig' => 'fadeInRightBig',
                                'fadeInUp' => 'fadeInUp',
                                'fadeInUpBig' => 'fadeInUpBig',
                                'flip' => 'flip',
                                'flipInX' => 'flipInX',
                                'flipInY' => 'flipInY',
                                'flipOutX' => 'flipOutX',
                                'flipOutY' => 'flipOutY',
                                'lightSpeedIn' => 'lightSpeedIn',
                                'rotateIn' => 'rotateIn',
                                'rotateInDownLeft' => 'rotateInDownLeft',
                                'rotateInDownRight' => 'rotateInDownRight',
                                'rotateInUpLeft' => 'rotateInUpLeft',
                                'rotateInUpRight' => 'rotateInUpRight',
                                'rollIn' => 'rollIn',
                                'zoomIn' => 'zoomIn',
                                'zoomInDown' => 'zoomInDown',
                                'zoomInLeft' => 'zoomInLeft',
                                'zoomInRight' => 'zoomInRight',
                                'zoomInUp' => 'zoomInUp'
                                
                            ),
                            'default'  => 'noanim'
                        ),
                        array(
                            'id'            => 'sm-mitems-anim-dur',
                            'type'          => 'slider',
                            'title'         => __( 'Menu Items Animation Duration (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Seconds for which the animation would run.', '_supermenu_' ),
                            'desc'          => __( '', '_supermenu_' ),
                            'default'       => 1.0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'            => 'sm-mitems-anim-delay',
                            'type'          => 'slider',
                            'title'         => __( 'Menu Items Animation Delay (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Menu Items Animation Delay.', '_supermenu_' ),
                            'desc'          => __( 'This is the interval after which the animation would trigger.', '_supermenu_' ),
                            'default'       => 0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'       => 'sm-dd-animation',
                            'type'     => 'select',
                            'title'    => __( 'Dropdown Items Animation', '_supermenu_' ),
                            'subtitle' => __( 'Choose the animation effect for your dropdown items.', '_supermenu_' ),
                            'desc'     => __( '', '_supermenu_' ),
                            //Must provide key => value pairs for select options
                            'options'  => array(
                                'noanim' => 'disabled',
                                'bounce' => 'bounce',
                                'bounceIn' => 'bounceIn',
                                'bounceInDown' => 'bounceInDown',
                                'bounceInLeft' => 'bounceInLeft',
                                'bounceInRight' => 'bounceInRight',
                                'bounceInUp' => 'bounceInUp',
                                'fadeIn' => 'fadeIn',
                                'fadeInDown' => 'fadeInDown',
                                'fadeInDownBig' => 'fadeInDownBig',
                                'fadeInLeft' => 'fadeInLeft',
                                'fadeInLeftBig' => 'fadeInLeftBig',
                                'fadeInRight' => 'fadeInRight',
                                'fadeInRightBig' => 'fadeInRightBig',
                                'fadeInUp' => 'fadeInUp',
                                'fadeInUpBig' => 'fadeInUpBig',
                                'flip' => 'flip',
                                'flipInX' => 'flipInX',
                                'flipInY' => 'flipInY',
                                'flipOutX' => 'flipOutX',
                                'flipOutY' => 'flipOutY',
                                'lightSpeedIn' => 'lightSpeedIn',
                                'rotateIn' => 'rotateIn',
                                'rotateInDownLeft' => 'rotateInDownLeft',
                                'rotateInDownRight' => 'rotateInDownRight',
                                'rotateInUpLeft' => 'rotateInUpLeft',
                                'rotateInUpRight' => 'rotateInUpRight',
                                'rollIn' => 'rollIn',
                                'zoomIn' => 'zoomIn',
                                'zoomInDown' => 'zoomInDown',
                                'zoomInLeft' => 'zoomInLeft',
                                'zoomInRight' => 'zoomInRight',
                                'zoomInUp' => 'zoomInUp'
                                
                            ),
                            'default'  => 'fadeIn'
                        ),
                         array(
                            'id'            => 'sm-dd-anim-dur',
                            'type'          => 'slider',
                            'title'         => __( 'Dropdown Animation Duration (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Seconds for which the dropdown animation would run.', '_supermenu_' ),
                            'desc'          => __( '', '_supermenu_' ),
                            'default'       => 0.5,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),
                        array(
                            'id'            => 'sm-dd-anim-delay',
                            'type'          => 'slider',
                            'title'         => __( 'Dropdown Animation Delay (seconds)', '_supermenu_' ),
                            'subtitle'      => __( 'Dropdown Animation Delay.', '_supermenu_' ),
                            'desc'          => __( 'Perhaps the most useless feature.', '_supermenu_' ),
                            'default'       => 0,
                            'min'           => 0,
                            'step'          => .1,
                            'max'           => 10,
                            'resolution'    => 0.1,
                            'display_value' => 'text'
                        ),

                ),
            );
            
            $this->sections[] = array(
                'title'     => __('Advanced Settings', '_supermenu_'),
                'desc'      => __('Menu Styling here', '_supermenu_'),
                'icon'      => 'el-icon-key',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                   	array(
												    'id'       => 'sm-outer-wrapper',
												    'type'     => 'text',
												    'title'    => __('Outer Wrapper', 'redux-framework-demo'),
												    'subtitle' => __('<a href="http://boldblocks.com/support/supermenu/what-is-outer-wrapper/" target="_blank">Details</a>', 'redux-framework-demo'),
												    'desc'     => __('This is the wrapper outside the whole navigation.', 'redux-framework-demo'),
												    'validate' => 'no_special_chars',
												    'msg'      => 'custom error message',
												    'default'  => ''
												),
										array(
												    'id'       => 'sm-inner-wrapper',
												    'type'     => 'text',
												    'title'    => __('Inner Wrapper.', 'redux-framework-demo'),
												    'subtitle' => __('<a href="http://boldblocks.com/support/supermenu/what-is-inner-wrapper/" target="_blank">Details</a>', 'redux-framework-demo'),
												    'desc'     => __('This is the wrapper inside navigation, wraps the logo and menu items.', 'redux-framework-demo'),
												    'validate' => 'no_special_chars',
												    'msg'      => 'custom error message',
												    'default'  => ''
												),
                    array(
                            'id'       => 'sm-custom-css',
                            'type'     => 'ace_editor',
                            'title'    => __( 'CSS Code', '_supermenu_' ),
                            'subtitle' => __( 'Paste your CSS code here.', '_supermenu_' ),
                            'mode'     => 'css',
                            'theme'    => 'monokai',
                            'desc'     => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
                            'default'  => ""
                        ),
                  ),
                  
            );
            
            $this->sections[] = array(
                'title'     => __('Import / Export', '_supermenu_'),
                'desc'      => __('Import and Export your Supermenu settings from file, text or URL.', '_supermenu_'),
                'icon'      => 'el-icon-refresh',
                'fields'    => array(
                    array(
                        'id'            => 'opt-import-export',
                        'type'          => 'import_export',
                        'title'         => 'Import Export',
                        'subtitle'      => 'Save and restore your Supermenu options',
                        'full_width'    => false,
                    ),
                ),
            );                     
                    
            $this->sections[] = array(
                'type' => 'divide',
            );

            $this->sections[] = array(
                'icon'      => 'el-icon-info-sign',
                'title'     => __('Support Information', '_supermenu_'),
                'desc'      => __('', '_supermenu_'),
                'fields'    => array(
                    array(
                        'id'        => 'opt-raw-info',
                        'type'      => 'raw',
                        'content'   => 'Supermenu is a plugin by BoldBlocks. For support, please visit <a href="http://boldblocks.com/support" target="_blank">http://boldblocks.com/support</a>',
                    )
                ),
            );

            if (file_exists(trailingslashit(dirname(__FILE__)) . 'README.html')) {
                $tabs['docs'] = array(
                    'icon'      => 'el-icon-book',
                    'title'     => __('Documentation', '_supermenu_'),
                    'content'   => nl2br(file_get_contents(trailingslashit(dirname(__FILE__)) . 'README.html'))
                );
            }
        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-1',
                'title'     => __('Theme Information 1', '_supermenu_'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', '_supermenu_')
            );

            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-2',
                'title'     => __('Theme Information 2', '_supermenu_'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', '_supermenu_')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', '_supermenu_');
        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                'opt_name' => 'supermenu',
                'display_name' => 'supermenu',
                'display_version' => '',
                'page_slug' => 'supermenu_options',
                'page_title' => 'Supermenu',
                'update_notice' => true,
                'intro_text' => '<p><strong><a target="_blank" class="nd" href="http://boldblocks.com/support/forums/forum/supermenu-forum/?utm_source=src_admin_top&utm_medium=mdm_admin_top&utm_campaign=support">SUPPORT AVAILABLE HERE.</a> | <a target="_blank" class="nd" href="http://boldblocks.com/support/forums/forum/supermenu-forum/?utm_source=src_admin_top&utm_medium=mdm_admin_top&utm_campaign=add_icons">A NEW WAY TO ADD ICONS</a> </strong></p>',
                'footer_text' => '<b>Supermenu</b>',
                'admin_bar' => true,
                'dev_mode' => false,
                'menu_type' => 'menu',
                'menu_title' => 'Supermenu',
                'menu_icon' => plugin_dir_url( __FILE__ ) . '../assets/img/icon.png',
                'allow_sub_menu' => true,
                'page_parent_post_type' => 'your_post_type',
                'default_show' => true,
                'default_mark' => '*',
                'class' => 'supermenu-container',
                'hints' => 
                array(
                  'icon' => 'el-icon-question-sign',
                  'icon_position' => 'right',
                  'icon_size' => 'normal',
                  'tip_style' => 
                  array(
                    'color' => 'light',
                  ),
                  'tip_position' => 
                  array(
                    'my' => 'top left',
                    'at' => 'bottom right',
                  ),
                  'tip_effect' => 
                  array(
                    'show' => 
                    array(
                      'duration' => '500',
                      'event' => 'mouseover',
                    ),
                    'hide' => 
                    array(
                      'duration' => '500',
                      'event' => 'mouseleave unfocus',
                    ),
                  ),
                ),
                'output' => true,
                'output_tag' => true,
                'compiler' => true,
                'page_icon' => 'icon-options-general',
                'page_permissions' => 'manage_options',
                'save_defaults' => true,
                'show_import_export' => true,
                'database' => 'options',
                'transient_time' => '3600',
                'network_sites' => true,
              );

            // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            
            //$this->args['share_icons'][] = array(
                //'url'   => 'https://www.facebook.com/boldblocks',
                //'title' => 'Like us on Facebook',
                //'icon'  => 'el-icon-facebook'
            //);
            //$this->args['share_icons'][] = array(
                //'url'   => 'http://twitter.com/boldblocks',
                //'title' => 'Follow us on Twitter',
                //'icon'  => 'el-icon-twitter'
            //);
            //$this->args['share_icons'][] = array(
                //'url'   => 'http://www.instagram.com/boldblocks',
                //'title' => 'Find us on Instagram',
                //'icon'  => 'el-icon-instagram'
            //);

        }

    }
    
    global $reduxConfig;
    $reduxConfig = new admin_folder_Redux_Framework_config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('admin_folder_my_custom_field')):
    function admin_folder_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('admin_folder_validate_callback_function')):
    function admin_folder_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        /*
          do your validation

          if(something) {
            $value = $value;
          } elseif(something else) {
            $error = true;
            $value = $existing_value;
            $field['msg'] = 'your custom error message';
          }
         */

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;
