<?php
/**
 * Font Awesome
 *
 * @package Menu_Icons
 * @author Dzikri Aziz <kvcrvt@gmail.com>
 */


require_once dirname( __FILE__ ) . '/type-fonts.php';

/**
 * Icon type: Font Awesome
 *
 */
class Menu_Icons_Type_Fontawesome extends Menu_Icons_Type_Fonts {

	/**
	 * Holds icon type
	 *
	 * @since  0.1.0
	 * @access protected
	 * @var    string
	 */
	protected $type = 'fa';

	/**
	 * Holds icon label
	 *
	 * @since  0.1.0
	 * @access protected
	 * @var    string
	 */
	protected $label = 'Font Awesome';

	/**
	 * Holds icon version
	 *
	 * @since  0.1.0
	 * @access protected
	 * @var    string
	 */
	protected $version = '4.2.0';


	/**
	 * Class constructor
	 *
	 * We need to override the parent's to set our stylesheet URL
	 *
	 * @since 0.1.0
	 * @param array $types Icon Types
	 * @return array
	 */
	public function __construct() {
		$this->stylesheet = sprintf(
			'%scss/font-awesome%s.css',
			Menu_Icons::get( 'url' ),
			Menu_Icons::get_script_suffix()
		);

		parent::__construct();
	}


	/**
	 * Genericons's icons names
	 *
	 * @since 0.1.0
	 * @return array
	 */
	public function get_names() {
		return array(
			array(
				'key'   => __( 'brand', '_supermenu_' ),
				'label' => __( 'Brand', '_supermenu_' ),
				'items' => array(
					'fa-adn'                => 'ADN',
					'fa-android'            => 'Android',
					'fa-angellist'          => 'AngelList',
					'fa-apple'              => 'Apple',
					'fa-behance'            => 'Behance',
					'fa-behance-square'     => 'Behance',
					'fa-bitbucket'          => 'Bitbucket',
					'fa-bitbucket-square'   => 'Bitucket Square',
					'fa-codepen'            => 'CodePen',
					'fa-css3'               => 'CSS3',
					'fa-delicious'          => 'Delicious',
					'fa-deviantart'         => 'deviantART',
					'fa-digg'               => 'Digg',
					'fa-dribbble'           => 'Dribbble',
					'fa-dropbox'            => 'DropBox',
					'fa-drupal'             => 'Drupal',
					'fa-empire'             => 'Empire',
					'fa-facebook'           => 'Facebook',
					'fa-facebook-square'    => 'Facebook',
					'fa-flickr'             => 'Flickr',
					'fa-foursquare'         => 'Foursquare',
					'fa-git'                => 'Git',
					'fa-git-square'         => 'Git',
					'fa-github'             => 'GitHub',
					'fa-github-alt'         => 'GitHub',
					'fa-github-square'      => 'GitHub',
					'fa-gittip'             => 'GitTip',
					'fa-google'             => 'Google',
					'fa-google-plus'        => 'Google+',
					'fa-google-plus-square' => 'Google+',
					'fa-hacker-news'        => 'Hacker News',
					'fa-html5'              => 'HTML5',
					'fa-instagram'          => 'Instagram',
					'fa-ioxhost'            => 'IoxHost',
					'fa-joomla'             => 'Joomla',
					'fa-jsfiddle'           => 'JSFiddle',
					'fa-lastfm'             => 'Last.fm',
					'fa-lastfm-square'      => 'Last.fm',
					'fa-linkedin'           => 'LinkedIn',
					'fa-linkedin-square'    => 'LinkedIn',
					'fa-linux'              => 'Linux',
					'fa-maxcdn'             => 'MaxCDN',
					'fa-meanpath'           => 'meanpath',
					'fa-openid'             => 'OpenID',
					'fa-pagelines'          => 'Pagelines',
					'fa-pied-piper'         => 'Pied Piper',
					'fa-pied-piper-alt'     => 'Pied Piper',
					'fa-pinterest'          => 'Pinterest',
					'fa-pinterest-square'   => 'Pinterest',
					'fa-qq'                 => 'QQ',
					'fa-reddit'             => 'reddit',
					'fa-reddit-square'      => 'reddit',
					'fa-renren'             => 'Renren',
					'fa-skype'              => 'Skype',
					'fa-slack'              => 'Slack',
					'fa-slideshare'         => 'SlideShare',
					'fa-soundcloud'         => 'SoundCloud',
					'fa-spotify'            => 'Spotify',
					'fa-stack-exchange'     => 'Stack Exchange',
					'fa-stack-overflow'     => 'Stack Overflow',
					'fa-steam'              => 'Steam',
					'fa-steam-square'       => 'Steam',
					'fa-stumbleupon'        => 'StumbleUpon',
					'fa-stumbleupon-circle' => 'StumbleUpon',
					'fa-tencent-weibo'      => 'Tencent Weibo',
					'fa-trello'             => 'Trello',
					'fa-tumblr'             => 'Tumblr',
					'fa-tumblr-square'      => 'Tumblr',
					'fa-twitch'             => 'Twitch',
					'fa-twitter'            => 'Twitter',
					'fa-twitter-square'     => 'Twitter',
					'fa-vimeo-square'       => 'Vimeo',
					'fa-vine'               => 'Vine',
					'fa-vk'                 => 'VK',
					'fa-weixin'             => 'Weixin',
					'fa-weibo'              => 'Wibo',
					'fa-windows'            => 'Windows',
					'fa-wordpress'          => 'WordPress',
					'fa-xing'               => 'Xing',
					'fa-xing-square'        => 'Xing',
					'fa-yahoo'              => 'Yahoo!',
					'fa-yelp'               => 'Yelp',
					'fa-youtube'            => 'YouTube',
					'fa-youtube-square'     => 'YouTube',
				),
			),
			array(
				'key'   => 'currency',
				'label' => __( 'Currency', '_supermenu_' ),
				'items' => array(
					'fa-bitcoin'      => __( 'Bitcoin', '_supermenu_' ),
					'fa-dollar'       => __( 'Dollar', '_supermenu_' ),
					'fa-euro'         => __( 'Euro', '_supermenu_' ),
					'fa-gbp'          => __( 'GBP', '_supermenu_' ),
					'fa-ils'          => __( 'Israeli Sheqel', '_supermenu_' ),
					'fa-money'        => __( 'Money', '_supermenu_' ),
					'fa-rouble'       => __( 'Rouble', '_supermenu_' ),
					'fa-inr'          => __( 'Rupee', '_supermenu_' ),
					'fa-try'          => __( 'Turkish Lira', '_supermenu_' ),
					'fa-krw'          => __( 'Won', '_supermenu_' ),
					'fa-jpy'          => __( 'Yen', '_supermenu_' ),
				),
			),
			array(
				'key'   => 'directional',
				'label' => __( 'Directional', '_supermenu_' ),
				'items' => array(
					'fa-angle-down'           => __( 'Angle Down', '_supermenu_' ),
					'fa-angle-left'           => __( 'Angle Left', '_supermenu_' ),
					'fa-angle-right'          => __( 'Angle Right', '_supermenu_' ),
					'fa-angle-up'             => __( 'Angle Up', '_supermenu_' ),
					'fa-angle-double-down'    => __( 'Angle Double Down', '_supermenu_' ),
					'fa-angle-double-left'    => __( 'Angle Double Left', '_supermenu_' ),
					'fa-angle-double-right'   => __( 'Angle Double Right', '_supermenu_' ),
					'fa-angle-double-up'      => __( 'Angle Double Up', '_supermenu_' ),
					'fa-arrow-circle-o-down'  => __( 'Arrow Circle Down', '_supermenu_' ),
					'fa-arrow-circle-o-left'  => __( 'Arrow Circle Left', '_supermenu_' ),
					'fa-arrow-circle-o-right' => __( 'Arrow Circle Right', '_supermenu_' ),
					'fa-arrow-circle-o-up'    => __( 'Arrow Circle Up', '_supermenu_' ),
					'fa-arrow-circle-down'    => __( 'Arrow Circle Down', '_supermenu_' ),
					'fa-arrow-circle-left'    => __( 'Arrow Circle Left', '_supermenu_' ),
					'fa-arrow-circle-right'   => __( 'Arrow Circle Right', '_supermenu_' ),
					'fa-arrow-circle-up'      => __( 'Arrow Circle Up', '_supermenu_' ),
					'fa-arrow-down'           => __( 'Arrow Down', '_supermenu_' ),
					'fa-arrow-left'           => __( 'Arrow Left', '_supermenu_' ),
					'fa-arrow-right'          => __( 'Arrow Right', '_supermenu_' ),
					'fa-arrow-up'             => __( 'Arrow Up', '_supermenu_' ),
					'fa-arrows'               => __( 'Arrows', '_supermenu_' ),
					'fa-arrows-alt'           => __( 'Arrows', '_supermenu_' ),
					'fa-arrows-h'             => __( 'Arrows', '_supermenu_' ),
					'fa-arrows-v'             => __( 'Arrows', '_supermenu_' ),
					'fa-caret-down'           => __( 'Caret Down', '_supermenu_' ),
					'fa-caret-left'           => __( 'Caret Left', '_supermenu_' ),
					'fa-caret-right'          => __( 'Caret Right', '_supermenu_' ),
					'fa-caret-up'             => __( 'Caret Up', '_supermenu_' ),
					'fa-caret-square-o-down'  => __( 'Caret Down', '_supermenu_' ),
					'fa-caret-square-o-left'  => __( 'Caret Left', '_supermenu_' ),
					'fa-caret-square-o-right' => __( 'Caret Right', '_supermenu_' ),
					'fa-caret-square-o-up'    => __( 'Caret Up', '_supermenu_' ),
					'fa-chevron-circle-down'  => __( 'Chevron Circle Down', '_supermenu_' ),
					'fa-chevron-circle-left'  => __( 'Chevron Circle Left', '_supermenu_' ),
					'fa-chevron-circle-right' => __( 'Chevron Circle Right', '_supermenu_' ),
					'fa-chevron-circle-up'    => __( 'Chevron Circle Up', '_supermenu_' ),
					'fa-chevron-down'         => __( 'Chevron Down', '_supermenu_' ),
					'fa-chevron-left'         => __( 'Chevron Left', '_supermenu_' ),
					'fa-chevron-right'        => __( 'Chevron Right', '_supermenu_' ),
					'fa-chevron-up'           => __( 'Chevron Up', '_supermenu_' ),
					'fa-hand-o-down'          => __( 'Hand Down', '_supermenu_' ),
					'fa-hand-o-left'          => __( 'Hand Left', '_supermenu_' ),
					'fa-hand-o-right'         => __( 'Hand Right', '_supermenu_' ),
					'fa-hand-o-up'            => __( 'Hand Up', '_supermenu_' ),
					'fa-long-arrow-down'      => __( 'Long Arrow Down', '_supermenu_' ),
					'fa-long-arrow-left'      => __( 'Long Arrow Left', '_supermenu_' ),
					'fa-long-arrow-right'     => __( 'Long Arrow Right', '_supermenu_' ),
					'fa-long-arrow-up'        => __( 'Long Arrow Up', '_supermenu_' ),
				),
			),
			array(
				'key'   => 'file-types',
				'label' => __( 'File Types', '_supermenu_' ),
				'items' => array(
					'fa-file'              => __( 'File', '_supermenu_' ),
					'fa-file-o'            => __( 'File', '_supermenu_' ),
					'fa-file-text'         => __( 'File: Text', '_supermenu_' ),
					'fa-file-text-o'       => __( 'File: Text', '_supermenu_' ),
					'fa-file-archive-o'    => __( 'File: Archive', '_supermenu_' ),
					'fa-file-audio-o'      => __( 'File: Audio', '_supermenu_' ),
					'fa-file-code-o'       => __( 'File: Code', '_supermenu_' ),
					'fa-file-excel-o'      => __( 'File: Excel', '_supermenu_' ),
					'fa-file-image-o'      => __( 'File: Image', '_supermenu_' ),
					'fa-file-pdf-o'        => __( 'File: PDF', '_supermenu_' ),
					'fa-file-powerpoint-o' => __( 'File: Powerpoint', '_supermenu_' ),
					'fa-file-video-o'      => __( 'File: Video', '_supermenu_' ),
					'fa-file-word-o'       => __( 'File: Word', '_supermenu_' ),
				),
			),
			array(
				'key'   => __( 'medical', '_supermenu_' ),
				'label' => __( 'Medical', '_supermenu_' ),
				'items' => array(
					'fa-ambulance'   => __( 'Ambulance', '_supermenu_' ),
					'fa-h-square'    => __( 'Hospital', '_supermenu_' ),
					'fa-hospital-o'  => __( 'Hospital', '_supermenu_' ),
					'fa-medkit'      => __( 'Medkit', '_supermenu_' ),
					'fa-stethoscope' => __( 'Stethoscope', '_supermenu_' ),
					'fa-user-md'     => __( 'User MD', '_supermenu_' ),
					'fa-wheelchair'  => __( 'Wheelchair', '_supermenu_' ),
				),
			),
			array(
				'key'   => 'payment',
				'label' => __( 'Payment', '_supermenu_' ),
				'items' => array(
					'fa-cc-amex'       => 'American Express',
					'fa-credit-card'   => __( 'Credit Card', '_supermenu_' ),
					'fa-cc-discover'   => 'Discover',
					'fa-google-wallet' => 'Google Wallet',
					'fa-cc-mastercard' => 'MasterCard',
					'fa-cc-paypal'     => 'PayPal',
					'fa-paypal'        => 'PayPal',
					'fa-cc-stripe'     => 'Stripe',
					'fa-cc-visa'       => 'Visa',
				),
			),
			array(
				'key'   => 'text-editor',
				'label' => __( 'Text Editor', '_supermenu_' ),
				'items' => array(
					'fa-align-left'    => __( 'Align Left', '_supermenu_' ),
					'fa-align-center'  => __( 'Align Center', '_supermenu_' ),
					'fa-align-justify' => __( 'Justify', '_supermenu_' ),
					'fa-align-right'   => __( 'Align Right', '_supermenu_' ),
					'fa-bold'          => __( 'Bold', '_supermenu_' ),
					'fa-clipboard'     => __( 'Clipboard', '_supermenu_' ),
					'fa-columns'       => __( 'Columns', '_supermenu_' ),
					'fa-copy'          => __( 'Copy', '_supermenu_' ),
					'fa-cut'           => __( 'Cut', '_supermenu_' ),
					'fa-paste'         => __( 'Paste', '_supermenu_' ),
					'fa-eraser'        => __( 'Eraser', '_supermenu_' ),
					'fa-files-o'       => __( 'Files', '_supermenu_' ),
					'fa-font'          => __( 'Font', '_supermenu_' ),
					'fa-indent'        => __( 'Indent', '_supermenu_' ),
					'fa-outdent'       => __( 'Outdent', '_supermenu_' ),
					'fa-italic'        => __( 'Italic', '_supermenu_' ),
					'fa-link'          => __( 'Link', '_supermenu_' ),
					'fa-unlink'        => __( 'Unlink', '_supermenu_' ),
					'fa-list'          => __( 'List', '_supermenu_' ),
					'fa-list-alt'      => __( 'List', '_supermenu_' ),
					'fa-list-ol'       => __( 'Ordered List', '_supermenu_' ),
					'fa-list-ul'       => __( 'Unordered List', '_supermenu_' ),
					'fa-paperclip'     => __( 'Paperclip', '_supermenu_' ),
					'fa-paragraph'     => __( 'Paragraph', '_supermenu_' ),
					'fa-repeat'        => __( 'Repeat', '_supermenu_' ),
					'fa-undo'          => __( 'Undo', '_supermenu_' ),
					'fa-save'          => __( 'Save', '_supermenu_' ),
					'fa-strikethrough' => __( 'Strikethrough', '_supermenu_' ),
					'fa-table'         => __( 'Table', '_supermenu_' ),
					'fa-text-height'   => __( 'Text Height', '_supermenu_' ),
					'fa-text-width'    => __( 'Text Width', '_supermenu_' ),
					'fa-th'            => __( 'TH', '_supermenu_' ),
					'fa-th-large'      => __( 'TH Large', '_supermenu_' ),
					'fa-th-list'       => __( 'TH List', '_supermenu_' ),
					'fa-underline'     => __( 'Underline', '_supermenu_' ),
				),
			),
			array(
				'key'   => 'video-player',
				'label' => __( 'Video Player', '_supermenu_' ),
				'items' => array(
					'fa-arrows-alt'    => __( 'Arrows', '_supermenu_' ),
					'fa-backward'      => __( 'Backward', '_supermenu_' ),
					'fa-compress'      => __( 'Compress', '_supermenu_' ),
					'fa-eject'         => __( 'Eject', '_supermenu_' ),
					'fa-expand'        => __( 'Expand', '_supermenu_' ),
					'fa-fast-backward' => __( 'Fast Backward', '_supermenu_' ),
					'fa-fast-forward'  => __( 'Fast Forward', '_supermenu_' ),
					'fa-forward'       => __( 'Forward', '_supermenu_' ),
					'fa-pause'         => __( 'Pause', '_supermenu_' ),
					'fa-play'          => __( 'Play', '_supermenu_' ),
					'fa-play-circle'   => __( 'Play', '_supermenu_' ),
					'fa-play-circle-o' => __( 'Play', '_supermenu_' ),
					'fa-step-backward' => __( 'Step Backward', '_supermenu_' ),
					'fa-step-forward'  => __( 'Step Forward', '_supermenu_' ),
					'fa-stop'          => __( 'Stop', '_supermenu_' ),
					'fa-youtube-play'  => sprintf( __( '%s Play', '_supermenu_' ), 'YouTube' ),
				),
			),
			array(
				'key'   => 'web-application',
				'label' => __( 'Web Application', '_supermenu_' ),
				'items' => array(
					'fa-adjust'               => __( 'Adjust', '_supermenu_' ),
					'fa-anchor'               => __( 'Anchor', '_supermenu_' ),
					'fa-archive'              => __( 'Archive', '_supermenu_' ),
					'fa-area-chart'           => __( 'Area Chart', '_supermenu_' ),
					'fa-arrows'               => __( 'Arrows', '_supermenu_' ),
					'fa-arrows-h'             => __( 'Arrows', '_supermenu_' ),
					'fa-arrows-v'             => __( 'Arrows', '_supermenu_' ),
					'fa-asterisk'             => __( 'Asterisk', '_supermenu_' ),
					'fa-at'                   => __( 'At', '_supermenu_' ),
					'fa-ban'                  => __( 'Ban', '_supermenu_' ),
					'fa-bar-chart-o'          => __( 'Bar Chart', '_supermenu_' ),
					'fa-barcode'              => __( 'Barcode', '_supermenu_' ),
					'fa-bars'                 => __( 'Bars', '_supermenu_' ),
					'fa-beer'                 => __( 'Beer', '_supermenu_' ),
					'fa-bell'                 => __( 'Bell', '_supermenu_' ),
					'fa-bell-o'               => __( 'Bell', '_supermenu_' ),
					'fa-bell-slash'           => __( 'Bell', '_supermenu_' ),
					'fa-bell-slash-o'         => __( 'Bell', '_supermenu_' ),
					'fa-bicycle'              => __( 'Bicycle', '_supermenu_' ),
					'fa-binoculars'           => __( 'Binoculars', '_supermenu_' ),
					'fa-birthday-cake'        => __( 'Birthday Cake', '_supermenu_' ),
					'fa-bolt'                 => __( 'Bolt', '_supermenu_' ),
					'fa-book'                 => __( 'Book', '_supermenu_' ),
					'fa-bookmark'             => __( 'Bookmark', '_supermenu_' ),
					'fa-bookmark-o'           => __( 'Bookmark', '_supermenu_' ),
					'fa-bomb'                 => __( 'Bomb', '_supermenu_' ),
					'fa-briefcase'            => __( 'Briefcase', '_supermenu_' ),
					'fa-bug'                  => __( 'Bug', '_supermenu_' ),
					'fa-building'             => __( 'Building', '_supermenu_' ),
					'fa-building-o'           => __( 'Building', '_supermenu_' ),
					'fa-bullhorn'             => __( 'Bullhorn', '_supermenu_' ),
					'fa-bullseye'             => __( 'Bullseye', '_supermenu_' ),
					'fa-bus'                  => __( 'Bus', '_supermenu_' ),
					'fa-calculator'           => __( 'Calculator', '_supermenu_' ),
					'fa-calendar'             => __( 'Calendar', '_supermenu_' ),
					'fa-calendar-o'           => __( 'Calendar', '_supermenu_' ),
					'fa-camera'               => __( 'Camera', '_supermenu_' ),
					'fa-camera-retro'         => __( 'Camera Retro', '_supermenu_' ),
					'fa-car'                  => __( 'Car', '_supermenu_' ),
					'fa-caret-square-o-down'  => __( 'Caret Down', '_supermenu_' ),
					'fa-caret-square-o-left'  => __( 'Caret Left', '_supermenu_' ),
					'fa-caret-square-o-right' => __( 'Caret Right', '_supermenu_' ),
					'fa-caret-square-o-up'    => __( 'Caret Up', '_supermenu_' ),
					'fa-certificate'          => __( 'Certificate', '_supermenu_' ),
					'fa-check'                => __( 'Check', '_supermenu_' ),
					'fa-check-circle'         => __( 'Check', '_supermenu_' ),
					'fa-check-circle-o'       => __( 'Check', '_supermenu_' ),
					'fa-check-square'         => __( 'Check', '_supermenu_' ),
					'fa-check-square-o'       => __( 'Check', '_supermenu_' ),
					'fa-child'                => __( 'Child', '_supermenu_' ),
					'fa-circle'               => __( 'Circle', '_supermenu_' ),
					'fa-circle-o'             => __( 'Circle', '_supermenu_' ),
					'fa-circle-o-notch'       => __( 'Circle', '_supermenu_' ),
					'fa-circle-thin'          => __( 'Circle', '_supermenu_' ),
					'fa-clock-o'              => __( 'Clock', '_supermenu_' ),
					'fa-cloud'                => __( 'Cloud', '_supermenu_' ),
					'fa-cloud-download'       => __( 'Cloud Download', '_supermenu_' ),
					'fa-cloud-upload'         => __( 'Cloud Upload', '_supermenu_' ),
					'fa-code'                 => __( 'Code', '_supermenu_' ),
					'fa-code-fork'            => __( 'Code Fork', '_supermenu_' ),
					'fa-coffee'               => __( 'Coffee', '_supermenu_' ),
					'fa-cog'                  => __( 'Cog', '_supermenu_' ),
					'fa-cogs'                 => __( 'Cogs', '_supermenu_' ),
					'fa-comment'              => __( 'Comment', '_supermenu_' ),
					'fa-comment-o'            => __( 'Comment', '_supermenu_' ),
					'fa-comments'             => __( 'Comments', '_supermenu_' ),
					'fa-comments-o'           => __( 'Comments', '_supermenu_' ),
					'fa-compass'              => __( 'Compass', '_supermenu_' ),
					'fa-copyright'            => __( 'Copyright', '_supermenu_' ),
					'fa-credit-card'          => __( 'Credit Card', '_supermenu_' ),
					'fa-crop'                 => __( 'Crop', '_supermenu_' ),
					'fa-crosshairs'           => __( 'Crosshairs', '_supermenu_' ),
					'fa-cube'                 => __( 'Cube', '_supermenu_' ),
					'fa-cubes'                => __( 'Cubes', '_supermenu_' ),
					'fa-cutlery'              => __( 'Cutlery', '_supermenu_' ),
					'fa-dashboard'            => __( 'Dashboard', '_supermenu_' ),
					'fa-database'             => __( 'Database', '_supermenu_' ),
					'fa-desktop'              => __( 'Desktop', '_supermenu_' ),
					'fa-dot-circle-o'         => __( 'Dot', '_supermenu_' ),
					'fa-download'             => __( 'Download', '_supermenu_' ),
					'fa-edit'                 => __( 'Edit', '_supermenu_' ),
					'fa-ellipsis-h'           => __( 'Ellipsis', '_supermenu_' ),
					'fa-ellipsis-v'           => __( 'Ellipsis', '_supermenu_' ),
					'fa-envelope'             => __( 'Envelope', '_supermenu_' ),
					'fa-envelope-o'           => __( 'Envelope', '_supermenu_' ),
					'fa-envelope-square'      => __( 'Envelope', '_supermenu_' ),
					'fa-eraser'               => __( 'Eraser', '_supermenu_' ),
					'fa-exchange'             => __( 'Exchange', '_supermenu_' ),
					'fa-exclamation'          => __( 'Exclamation', '_supermenu_' ),
					'fa-exclamation-circle'   => __( 'Exclamation', '_supermenu_' ),
					'fa-exclamation-triangle' => __( 'Exclamation', '_supermenu_' ),
					'fa-external-link'        => __( 'External Link', '_supermenu_' ),
					'fa-external-link-square' => __( 'External Link', '_supermenu_' ),
					'fa-eye'                  => __( 'Eye', '_supermenu_' ),
					'fa-eye-slash'            => __( 'Eye', '_supermenu_' ),
					'fa-eyedropper'           => __( 'Eye Dropper', '_supermenu_' ),
					'fa-fax'                  => __( 'Fax', '_supermenu_' ),
					'fa-female'               => __( 'Female', '_supermenu_' ),
					'fa-fighter-jet'          => __( 'Fighter Jet', '_supermenu_' ),
					'fa-film'                 => __( 'Film', '_supermenu_' ),
					'fa-filter'               => __( 'Filter', '_supermenu_' ),
					'fa-fire'                 => __( 'Fire', '_supermenu_' ),
					'fa-fire-extinguisher'    => __( 'Fire Extinguisher', '_supermenu_' ),
					'fa-flag'                 => __( 'Flag', '_supermenu_' ),
					'fa-flag-checkered'       => __( 'Flag', '_supermenu_' ),
					'fa-flag-o'               => __( 'Flag', '_supermenu_' ),
					'fa-flash'                => __( 'Flash', '_supermenu_' ),
					'fa-flask'                => __( 'Flask', '_supermenu_' ),
					'fa-folder'               => __( 'Folder', '_supermenu_' ),
					'fa-folder-open'          => __( 'Folder Open', '_supermenu_' ),
					'fa-folder-o'             => __( 'Folder', '_supermenu_' ),
					'fa-folder-open-o'        => __( 'Folder Open', '_supermenu_' ),
					'fa-futbol-o'             => __( 'Foot Ball', '_supermenu_' ),
					'fa-frown-o'              => __( 'Frown', '_supermenu_' ),
					'fa-gamepad'              => __( 'Gamepad', '_supermenu_' ),
					'fa-gavel'                => __( 'Gavel', '_supermenu_' ),
					'fa-gear'                 => __( 'Gear', '_supermenu_' ),
					'fa-gears'                => __( 'Gears', '_supermenu_' ),
					'fa-gift'                 => __( 'Gift', '_supermenu_' ),
					'fa-glass'                => __( 'Glass', '_supermenu_' ),
					'fa-globe'                => __( 'Globe', '_supermenu_' ),
					'fa-graduation-cap'       => __( 'Graduation Cap', '_supermenu_' ),
					'fa-group'                => __( 'Group', '_supermenu_' ),
					'fa-hdd-o'                => __( 'HDD', '_supermenu_' ),
					'fa-header'               => __( 'Header', '_supermenu_' ),
					'fa-headphones'           => __( 'Headphones', '_supermenu_' ),
					'fa-heart'                => __( 'Heart', '_supermenu_' ),
					'fa-heart-o'              => __( 'Heart', '_supermenu_' ),
					'fa-home'                 => __( 'Home', '_supermenu_' ),
					'fa-history'              => __( 'History', '_supermenu_' ),
					'fa-inbox'                => __( 'Inbox', '_supermenu_' ),
					'fa-info'                 => __( 'Info', '_supermenu_' ),
					'fa-info-circle'          => __( 'Info', '_supermenu_' ),
					'fa-key'                  => __( 'Key', '_supermenu_' ),
					'fa-keyboard-o'           => __( 'Keyboard', '_supermenu_' ),
					'fa-language'             => __( 'Language', '_supermenu_' ),
					'fa-laptop'               => __( 'Laptop', '_supermenu_' ),
					'fa-leaf'                 => __( 'Leaf', '_supermenu_' ),
					'fa-legal'                => __( 'Legal', '_supermenu_' ),
					'fa-lemon-o'              => __( 'Lemon', '_supermenu_' ),
					'fa-level-down'           => __( 'Level Down', '_supermenu_' ),
					'fa-level-up'             => __( 'Level Up', '_supermenu_' ),
					'fa-life-ring'            => __( 'Life Buoy', '_supermenu_' ),
					'fa-lightbulb-o'          => __( 'Lightbulb', '_supermenu_' ),
					'fa-line-chart'           => __( 'Line Chart', '_supermenu_' ),
					'fa-location-arrow'       => __( 'Location Arrow', '_supermenu_' ),
					'fa-lock'                 => __( 'Lock', '_supermenu_' ),
					'fa-magic'                => __( 'Magic', '_supermenu_' ),
					'fa-magnet'               => __( 'Magnet', '_supermenu_' ),
					'fa-mail-forward'         => __( 'Mail Forward', '_supermenu_' ),
					'fa-mail-reply'           => __( 'Mail Reply', '_supermenu_' ),
					'fa-mail-reply-all'       => __( 'Mail Reply All', '_supermenu_' ),
					'fa-male'                 => __( 'Male', '_supermenu_' ),
					'fa-map-marker'           => __( 'Map Marker', '_supermenu_' ),
					'fa-meh-o'                => __( 'Meh', '_supermenu_' ),
					'fa-microphone'           => __( 'Microphone', '_supermenu_' ),
					'fa-microphone-slash'     => __( 'Microphone', '_supermenu_' ),
					'fa-minus'                => __( 'Minus', '_supermenu_' ),
					'fa-minus-circle'         => __( 'Minus', '_supermenu_' ),
					'fa-minus-square'         => __( 'Minus', '_supermenu_' ),
					'fa-minus-square-o'       => __( 'Minus', '_supermenu_' ),
					'fa-mobile'               => __( 'Mobile', '_supermenu_' ),
					'fa-mobile-phone'         => __( 'Mobile Phone', '_supermenu_' ),
					'fa-moon-o'               => __( 'Moon', '_supermenu_' ),
					'fa-music'                => __( 'Music', '_supermenu_' ),
					'fa-newspaper-o'          => __( 'Newspaper', '_supermenu_' ),
					'fa-paint-brush'          => __( 'Paint Brush', '_supermenu_' ),
					'fa-paper-plane'          => __( 'Paper Plane', '_supermenu_' ),
					'fa-paper-plane-o'        => __( 'Paper Plane', '_supermenu_' ),
					'fa-paw'                  => __( 'Paw', '_supermenu_' ),
					'fa-pencil'               => __( 'Pencil', '_supermenu_' ),
					'fa-pencil-square'        => __( 'Pencil', '_supermenu_' ),
					'fa-pencil-square-o'      => __( 'Pencil', '_supermenu_' ),
					'fa-phone'                => __( 'Phone', '_supermenu_' ),
					'fa-phone-square'         => __( 'Phone', '_supermenu_' ),
					'fa-picture-o'            => __( 'Picture', '_supermenu_' ),
					'fa-pie-chart'            => __( 'Pie Chart', '_supermenu_' ),
					'fa-plane'                => __( 'Plane', '_supermenu_' ),
					'fa-plug'                 => __( 'Plug', '_supermenu_' ),
					'fa-plus'                 => __( 'Plus', '_supermenu_' ),
					'fa-plus-circle'          => __( 'Plus', '_supermenu_' ),
					'fa-plus-square'          => __( 'Plus', '_supermenu_' ),
					'fa-plus-square-o'        => __( 'Plus', '_supermenu_' ),
					'fa-power-off'            => __( 'Power Off', '_supermenu_' ),
					'fa-print'                => __( 'Print', '_supermenu_' ),
					'fa-puzzle-piece'         => __( 'Puzzle Piece', '_supermenu_' ),
					'fa-qrcode'               => __( 'QR Code', '_supermenu_' ),
					'fa-question'             => __( 'Question', '_supermenu_' ),
					'fa-question-circle'      => __( 'Question', '_supermenu_' ),
					'fa-quote-left'           => __( 'Quote Left', '_supermenu_' ),
					'fa-quote-right'          => __( 'Quote Right', '_supermenu_' ),
					'fa-random'               => __( 'Random', '_supermenu_' ),
					'fa-rebel'                => __( 'Rebel', '_supermenu_' ),
					'fa-recycle'              => __( 'Recycle', '_supermenu_' ),
					'fa-refresh'              => __( 'Refresh', '_supermenu_' ),
					'fa-reply'                => __( 'Reply', '_supermenu_' ),
					'fa-reply-all'            => __( 'Reply All', '_supermenu_' ),
					'fa-retweet'              => __( 'Retweet', '_supermenu_' ),
					'fa-road'                 => __( 'Road', '_supermenu_' ),
					'fa-rocket'               => __( 'Rocket', '_supermenu_' ),
					'fa-rss'                  => __( 'RSS', '_supermenu_' ),
					'fa-rss-square'           => __( 'RSS Square', '_supermenu_' ),
					'fa-search'               => __( 'Search', '_supermenu_' ),
					'fa-search-minus'         => __( 'Search Minus', '_supermenu_' ),
					'fa-search-plus'          => __( 'Search Plus', '_supermenu_' ),
					'fa-share'                => __( 'Share', '_supermenu_' ),
					'fa-share-alt'            => __( 'Share', '_supermenu_' ),
					'fa-share-alt-square'     => __( 'Share', '_supermenu_' ),
					'fa-share-square'         => __( 'Share', '_supermenu_' ),
					'fa-share-square-o'       => __( 'Share', '_supermenu_' ),
					'fa-shield'               => __( 'Shield', '_supermenu_' ),
					'fa-shopping-cart'        => __( 'Shopping Cart', '_supermenu_' ),
					'fa-sign-in'              => __( 'Sign In', '_supermenu_' ),
					'fa-sign-out'             => __( 'Sign Out', '_supermenu_' ),
					'fa-signal'               => __( 'Signal', '_supermenu_' ),
					'fa-sitemap'              => __( 'Sitemap', '_supermenu_' ),
					'fa-sliders'              => __( 'Sliders', '_supermenu_' ),
					'fa-smile-o'              => __( 'Smile', '_supermenu_' ),
					'fa-sort'                 => __( 'Sort', '_supermenu_' ),
					'fa-sort-asc'             => __( 'Sort ASC', '_supermenu_' ),
					'fa-sort-desc'            => __( 'Sort DESC', '_supermenu_' ),
					'fa-sort-down'            => __( 'Sort Down', '_supermenu_' ),
					'fa-sort-up'              => __( 'Sort Up', '_supermenu_' ),
					'fa-sort-alpha-asc'       => __( 'Sort Alpha ASC', '_supermenu_' ),
					'fa-sort-alpha-desc'      => __( 'Sort Alpha DESC', '_supermenu_' ),
					'fa-sort-amount-asc'      => __( 'Sort Amount ASC', '_supermenu_' ),
					'fa-sort-amount-desc'     => __( 'Sort Amount DESC', '_supermenu_' ),
					'fa-sort-numeric-asc'     => __( 'Sort Numeric ASC', '_supermenu_' ),
					'fa-sort-numeric-desc'    => __( 'Sort Numeric DESC', '_supermenu_' ),
					'fa-space-shuttle'        => __( 'Space Shuttle', '_supermenu_' ),
					'fa-spoon'                => __( 'Spoon', '_supermenu_' ),
					'fa-spinner'              => __( 'Spinner', '_supermenu_' ),
					'fa-square'               => __( 'Square', '_supermenu_' ),
					'fa-square-o'             => __( 'Square', '_supermenu_' ),
					'fa-star'                 => __( 'Star', '_supermenu_' ),
					'fa-star-half'            => __( 'Star Half', '_supermenu_' ),
					'fa-star-half-o'          => __( 'Star Half', '_supermenu_' ),
					'fa-star-half-empty'      => __( 'Star Half Empty', '_supermenu_' ),
					'fa-star-half-full'       => __( 'Star Half Full', '_supermenu_' ),
					'fa-star-o'               => __( 'Star', '_supermenu_' ),
					'fa-subscript'            => __( 'Subscript', '_supermenu_' ),
					'fa-suitcase'             => __( 'Suitcase', '_supermenu_' ),
					'fa-sun-o'                => __( 'Sun', '_supermenu_' ),
					'fa-superscript'          => __( 'Superscript', '_supermenu_' ),
					'fa-tablet'               => __( 'Tablet', '_supermenu_' ),
					'fa-tachometer'           => __( 'Tachometer', '_supermenu_' ),
					'fa-tag'                  => __( 'Tag', '_supermenu_' ),
					'fa-tags'                 => __( 'Tags', '_supermenu_' ),
					'fa-tasks'                => __( 'Tasks', '_supermenu_' ),
					'fa-taxi'                 => __( 'Taxi', '_supermenu_' ),
					'fa-terminal'             => __( 'Terminal', '_supermenu_' ),
					'fa-thumb-tack'           => __( 'Thumb Tack', '_supermenu_' ),
					'fa-thumbs-down'          => __( 'Thumbs Down', '_supermenu_' ),
					'fa-thumbs-up'            => __( 'Thumbs Up', '_supermenu_' ),
					'fa-thumbs-o-down'        => __( 'Thumbs Down', '_supermenu_' ),
					'fa-thumbs-o-up'          => __( 'Thumbs Up', '_supermenu_' ),
					'fa-ticket'               => __( 'Ticket', '_supermenu_' ),
					'fa-times'                => __( 'Times', '_supermenu_' ),
					'fa-times-circle'         => __( 'Times', '_supermenu_' ),
					'fa-times-circle-o'       => __( 'Times', '_supermenu_' ),
					'fa-tint'                 => __( 'Tint', '_supermenu_' ),
					'fa-toggle-down'          => __( 'Toggle Down', '_supermenu_' ),
					'fa-toggle-left'          => __( 'Toggle Left', '_supermenu_' ),
					'fa-toggle-right'         => __( 'Toggle Right', '_supermenu_' ),
					'fa-toggle-up'            => __( 'Toggle Up', '_supermenu_' ),
					'fa-toggle-off'           => __( 'Toggle Off', '_supermenu_' ),
					'fa-toggle-on'            => __( 'Toggle On', '_supermenu_' ),
					'fa-trash'                => __( 'Trash', '_supermenu_' ),
					'fa-tree'                 => __( 'Tree', '_supermenu_' ),
					'fa-trash-o'              => __( 'Trash', '_supermenu_' ),
					'fa-trophy'               => __( 'Trophy', '_supermenu_' ),
					'fa-truck'                => __( 'Truck', '_supermenu_' ),
					'fa-tty'                  => __( 'TTY', '_supermenu_' ),
					'fa-umbrella'             => __( 'Umbrella', '_supermenu_' ),
					'fa-university'           => __( 'University', '_supermenu_' ),
					'fa-unlock'               => __( 'Unlock', '_supermenu_' ),
					'fa-unlock-alt'           => __( 'Unlock', '_supermenu_' ),
					'fa-unsorted'             => __( 'Unsorted', '_supermenu_' ),
					'fa-upload'               => __( 'Upload', '_supermenu_' ),
					'fa-user'                 => __( 'User', '_supermenu_' ),
					'fa-users'                => __( 'Users', '_supermenu_' ),
					'fa-video-camera'         => __( 'Video Camera', '_supermenu_' ),
					'fa-volume-down'          => __( 'Volume Down', '_supermenu_' ),
					'fa-volume-off'           => __( 'Volume Of', '_supermenu_' ),
					'fa-volume-up'            => __( 'Volume Up', '_supermenu_' ),
					'fa-warning'              => __( 'Warning', '_supermenu_' ),
					'fa-wifi'                 => __( 'WiFi', '_supermenu_' ),
					'fa-wrench'               => __( 'Wrench', '_supermenu_' ),
				),
			),
		);
	}
}
